﻿-- My first WoW add-on
-- Should scan trade skill windows and determine which recipes are missing
-- Not localized.  Working on getting this to work with First Aid recipes first, then I will extend to enchanting, then the remaining skills.
-- As this is my first add-on I am still learning, and as you may notice I have a lot of comments.  If you modify anything please comment it so I know what the heck is going on
-- Thanks to FGTradeLacker for guiding me through writing this add-on and the Your first Ace2 Addon tutorial

-- BUGS:
-- Headings don't expand properly

AckisRecipeList = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0")

-- Namespace for an array containing recipes
RecipeListing = nil;
SkillType = nil;
FoundRecipes = nil;
NumberOfRecipes = nil;

-- Command line options for the mod.
-- Allows you to filter which recipes to display based on faction, class, profession speciality, rare raid recipes, and current/max skill level

local command_options = {
    type = "group",
    args =
	{
		scan =
		{
			type = "execute",
			name = "scan",
			desc = "Starts the recipe scan.",
			func = "AckisRecipeList_Command",
			order = 1,
		},
    	title =
		{
    		type = "header",
    		name = "Ackis Recipe List Configuration",
    		order = 2,
    	},
        display =
		{
            type = "group",
			name = "Display",
			desc = "Set which recipes to include in list",
			args =
				{
				all_factions =
					{
                    name      = "All Factions",
                    desc      = "Display all faction recipes or only your own faction.",
                    type      = "toggle",
                    get       = "GetAllFactions",
                    set       = "ToggleAllFactions",
                    order     = 1,
					},
				all_classes =
					{
                    name      = "All Classes",
                    desc      = "Display all class specific recipes or only your own.",
                    type      = "toggle",
                    get       = "GetAllClasses",
                    set       = "ToggleAllClasses",
                    order     = 2,
					},
				all_specialities =
					{
                    name      = "All Specialities",
                    desc      = "Display all trade skill recipes regardless of speciality.",
                    type      = "toggle",
                    get       = "GetAllSpecialities",
                    set       = "ToggleAllSpecialities",
                    order     = 3,
					},
				raid_recipes =
					{
                    name      = "Raid Recipes",
                    desc      = "Display hard to get raid only recipes.",
                    type      = "toggle",
                    get       = "GetAllRaid",
                    set       = "ToggleAllRaid",
                    order     = 4,
					},
				all_recipes =
					{
                    name      = "Skill Level",
                    desc      = "Display all recipes regardless of current skill level.",
                    type      = "toggle",
                    get       = "GetAllSkill",
                    set       = "ToggleAllSkill",
                    order     = 5,
					}
				}
		}
	}
}

-- Initialize the database and set the default options

AckisRecipeList:RegisterDB("AckisRecipeListDB", "AckisRecipeListDBPC");

AckisRecipeList:RegisterDefaults("profile",
	{
    AllFactions = false,
	AllClasses = false,
	AllSpecialities = false,
	AllRaid = false,
	AllSkill = false,
	}
);

-- Returns the boolean value of the AllFactions variable in the database.

function AckisRecipeList:GetAllFactions()

	return AckisRecipeList.db.profile.AllFactions;

end

-- Toggles the boolean value of the AllFactions variable in the database.

function AckisRecipeList:ToggleAllFactions()

	AckisRecipeList.db.profile.AllFactions = not AckisRecipeList.db.profile.AllFactions;

end

-- Returns the boolean value of the AllClasses variable in the database.

function AckisRecipeList:GetAllClasses()

	return AckisRecipeList.db.profile.AllClasses;

end

-- Sets the boolean value of the AllClasses variable in the database.

function AckisRecipeList:ToggleAllClasses()

	AckisRecipeList.db.profile.AllClasses = not AckisRecipeList.db.profile.AllClasses;

end

-- Returns the boolean value of the AllSpecialities variable in the database.

function AckisRecipeList:GetAllSpecialities()

	return AckisRecipeList.db.profile.AllSpecialities;

end

-- Sets the boolean value of the AllSpecialities variable in the database.

function AckisRecipeList:ToggleAllSpecialities()

	AckisRecipeList.db.profile.AllSpecialities = not AckisRecipeList.db.profile.AllSpecialities;

end

-- Returns the boolean value of the AllRaid variable in the database.

function AckisRecipeList:GetAllRaid()

	return AckisRecipeList.db.profile.AllRaid;

end

-- Sets the boolean value of the AllRaid variable in the database.

function AckisRecipeList:ToggleAllRaid()

	AckisRecipeList.db.profile.AllRaid = not AckisRecipeList.db.profile.AllRaid;

end

-- Returns the value of the AllSkill variable in the database.

function AckisRecipeList:GetAllSkill()

	return AckisRecipeList.db.profile.AllSkill;

end

-- Sets the boolean value of the AllSkill variable in the database.

function AckisRecipeList:ToggleAllSkill()

	AckisRecipeList.db.profile.AllSkill = not AckisRecipeList.db.profile.AllSkill;

end

-- When the add-on is enabled, register the version number, slash commands, and which events to watch

function AckisRecipeList:OnEnable()

	-- Add slash commands
	self:RegisterChatCommand("/AckisRecipeList", "/arl", command_options);

	-- Make addon respond to the tradeskill and crafting windows being shown
	self:RegisterEvent("TRADE_SKILL_SHOW");
	self:RegisterEvent("CRAFT_SHOW");

	-- Addon responds to tradeskill and crafting windows being closed.
	self:RegisterEvent("CRAFT_CLOSE");
	self:RegisterEvent("TRADE_SKILL_CLOSE");

end

-- Watch for the trade skill window to be shown, add all specific trade skills to an array, then scan the trade skill window for all recipes.

function AckisRecipeList:TRADE_SKILL_SHOW()

	SkillType = "Trade";

end

-- Clean up tables from memory when trade skill window is closed

function AckisRecipeList:TRADE_SKILL_CLOSE()

	AckisRecipeList:ResetVariables();

end

-- Watch for the craft skill window to be shown, add all specific trade skills to an array, then scan the craft skill window for all recipes.

function AckisRecipeList:CRAFT_SHOW()

	SkillType = "Craft";

end

-- Clean up tables from memory when craft window is closed

function AckisRecipeList:CRAFT_CLOSE()

	AckisRecipeList:ResetVariables();

end

-- Reset all variables

function AckisRecipeList:ResetVariables()

	if ( RecipeListing ~= nil) then

		local CurrentRecipe = next(RecipeListing,nil);

		while (CurrentRecipe ~= nil) do

			RecipeListing[ CurrentRecipe ][ "Level" ] = nil;
			RecipeListing[ CurrentRecipe ][ "Acquire" ] = nil;
			RecipeListing[ CurrentRecipe ][ "Speciality" ] = nil;		
			RecipeListing[ CurrentRecipe ][ "Known" ] = nil;

			local OldRecipe = CurrentRecipe;

			-- Move on to the next entry in the table
			CurrentRecipe = next(RecipeListing, CurrentRecipe);

			RecipeListing[ OldRecipe ] = nil;

		end

	end

	RecipeList = nil;
	SkillType = nil;
	FoundRecipes = nil;
	NumberOfRecipes = nil;

end

-- Initializes the initial recipe array, reseting it completely.

function AckisRecipeList:InitializeRecipeArray()

	-- Reset namespace to be empty
	RecipeListing = {};
  
	-- Sets the total number of recipes to 0.
	NumberOfRecipes = 0;

	-- Sets the number of found recipes to 0.
	FoundRecipes = 0;

end

-- Adds a specifc recipe to the recipe list array.  Also provides information regarding recipe level, if there is any trade skill recipe speciality, how to aquire the recipe, and if the recipe is known or not.

function addTradeSkill(RecipeName, RecipeLevel, RecipeAquire, RecipeSpeciality, RecipeKnown)

	-- Creates a table in the RecipeListing table storing all information about a recipe
	RecipeListing[ RecipeName ] = {};
	RecipeListing[ RecipeName ][ "Level" ] = RecipeLevel;
	RecipeListing[ RecipeName ][ "Acquire" ] = RecipeAquire;

	-- Since I can't make the function polymorphed, have if/thens to deal with getting 3, 4 or 5 variables as input for the function

	-- If function is called with 3 variables
	if (RecipeSpeciality == nil) then

		RecipeListing[ RecipeName ][ "Speciality" ] = {};

	else

		RecipeListing[ RecipeName ][ "Specialty" ] = RecipeSpecialty;

	end

	-- If function is called with 4 variables
	if (RecipeKnown == nil) then

		RecipeListing[ RecipeName ][ "Known" ] = false;

	else

		RecipeListing[ RecipeName ][ "Known" ] = RecipeKnown;

	end

	-- Increment the total number of recipes added to the list
	NumberOfRecipes = NumberOfRecipes + 1;

end

-- Modifies recipe array if a recipe is found, setting the Known flag as true.

function AckisRecipeList:foundTradeSkill(RecipeName)

	RecipeListing[ RecipeName ][ "Known" ] = true;

	-- Increase found count
	FoundRecipes = FoundRecipes + 1;

end

-- Prints out to chat a message stating that a current recipe is missing from the internal database.

function AckisRecipeList:printMissingSkill(RecipeName)

	DEFAULT_CHAT_FRAME:AddMessage( "The recipe " .. RecipeName .. " is currently not in the database.  Please report this to the author of the add-on.");

end

-- Prints out to chat the recipe and where it can be found.

function AckisRecipeList:PrintRecipeInfo(RecipeName)

	if (RecipeListing[ RecipeName ][ "Acquire" ] ~= nil) then

		DEFAULT_CHAT_FRAME:AddMessage(RecipeName .. " not found.  It is obtained via: " .. RecipeListing[ RecipeName ][ "Acquire" ]);

	else

		DEFAULT_CHAT_FRAME:AddMessage(RecipeName .. " not found.");

	end

end

-- Displays a summary of known recipes, total recipes and percentages.

function AckisRecipeList:PrintRecipeListSummary()

	DEFAULT_CHAT_FRAME:AddMessage("You know " .. FoundRecipes .. " out of " .. NumberOfRecipes .. " total recipes.");

end

-- Determines which recipes are known and which are not known, printing them out to the chat frame.

function AckisRecipeList:DisplayRecipeResults()

	-- Parse the recipe listing table
	if ( RecipeListing ~= nil ) then

		local CurrentRecipe = next(RecipeListing,nil);

			while (CurrentRecipe ~= nil) do

				-- If the recipe is not known then print out the info
				if ( RecipeListing[ CurrentRecipe ][ "Known" ] == false ) then

					AckisRecipeList:PrintRecipeInfo(CurrentRecipe);

				end

			-- Move on to the next entry in the table
			CurrentRecipe = next(RecipeListing, CurrentRecipe);
	
			end

	end

	AckisRecipeList:PrintRecipeListSummary();

end

-- Initializes the array adding all Alchemy recipes.  As of 2.2 there are

function AckisRecipeList:InitAlchemy()

	AckisRecipeList.InitializeRecipeArray();

	-- Original Game Recipes
	addTradeSkill( "Minor Healing Potion", 1, "Trainer" );
	addTradeSkill( "Elixir of Lion's Strength", 1, "Trainer" );
	addTradeSkill( "Elixir of Minor Defense", 1, "Trainer" );
	addTradeSkill( "Weak Troll's Blood Potion", 15, "Trainer" );
	addTradeSkill( "Minor Mana Potion", 25, "Trainer" );
	addTradeSkill( "Minor Rejuvenation Potion", 40, "Trainer" );
	addTradeSkill( "Elixir of Minor Agility", 50, "Uncommon World Drop" );
	addTradeSkill( "Discolored Healing Potion", 50, "Quest Reward", "Horde" );
	addTradeSkill( "Elixir of Minor Fortitude", 50, "Trainer" );
	addTradeSkill( "Lesser Healing Potion", 55, "Trainer" );
	addTradeSkill( "Rage Potion", 60, "Vendor" );
	addTradeSkill( "Swiftness Potion", 60, "Uncommon World Drop" );
	addTradeSkill( "Blackmouth Oil", 80, "Trainer" );
	addTradeSkill( "Elixir of Wisdom", 90, "Trainer" );
	addTradeSkill( "Elixir of Water Breathing", 90, "Trainer" );
	addTradeSkill( "Elixir of Giant Growth", 90, "Uncommon World Drop" );
	addTradeSkill( "Holy Protection Potion", 100, "Vendor" );
	addTradeSkill( "Swim Speed Potion", 100, "Trainer" );
	addTradeSkill( "Minor Magic Resistance Potion", 110, "Uncommon World Drop" );
	addTradeSkill( "Healing Potion", 110, "Trainer" );
	addTradeSkill( "Lesser Mana Potion", 120, "Trainer" );
	addTradeSkill( "Elixir of Poison Resistance", 120, "Uncommon World Drop" );
	addTradeSkill( "Strong Troll's Blood Potion", 125, "Trainer" );
	addTradeSkill( "Elixir of Defense", 130, "Trainer" );
	addTradeSkill( "Fire Oil", 130, "Trainer" );
	addTradeSkill( "Shadow Protection Potion", 135, "Vendor" );
	addTradeSkill( "Elixir of Lesser Agility", 140, "World Drop (Buy on AH)" );
	addTradeSkill( "Elixir of Firepower", 140, "Trainer" );
	addTradeSkill( "Elixir of Ogre's Strength", 150, "Uncommon World Drop" );
	addTradeSkill( "Free Action Potion", 150, "Vendor" );
	addTradeSkill( "Greater Healing Potion", 155, "Trainer" );
	addTradeSkill( "Mana Potion", 160, "Trainer" );
	addTradeSkill( "Lesser Invisibility Potion", 165, "Trainer" );
	addTradeSkill( "Shadow Oil", 165, "Vendor" );
	addTradeSkill( "Fire Protection Potion", 165, "Vendor" );
	addTradeSkill( "Elixir of Fortitude", 175, "Uncommon World Drop" );
	addTradeSkill( "Great Rage Potion", 175, "Vendor" );
	addTradeSkill( "Mighty Troll's Blood Potion", 180, "Talk to Henry Stern in RFD, or Uncommon World Drop" );
	addTradeSkill( "Elixir of Agility", 185, "Trainer" );
	addTradeSkill( "Frost Protection Potion", 190, "Vendor" );
	addTradeSkill( "Nature Protection Potion", 190, "Vendor" );
	addTradeSkill( "Elixir of Frost Power", 190, "You can get this randomly as a reward from a christmas quest.  It's also a drop from Father Winter" );
	addTradeSkill( "Elixir of Detect Lesser Invisibility", 195, "Uncommon World Drop" );
	addTradeSkill( "Elixir of Greater Defense", 195, "Trainer" );
	addTradeSkill( "Frost Oil", 200, "Vendor" );
	addTradeSkill( "Catseye Elixir", 200, "Trainer" );
	addTradeSkill( "Oil of Immolation", 205, "Trainer" );
	addTradeSkill( "Greater Mana Potion", 205, "Trainer" );
	addTradeSkill( "Magic Resistance Potion", 210, "Uncommon World Drop" );
	addTradeSkill( "Goblin Rocket Fuel", 210, "Vendor" );
	addTradeSkill( "Lesser Stoneshield Potion", 215, "From quest chain from Lotwil Veriatus, or you can just buy it on the AH from somebody else who has completed it" );
	addTradeSkill( "Restorative Potion", 215, "This will automatically be trained if you complete the Uldaman Reagent Run quest" );
	addTradeSkill( "Superior Healing Potion", 215, "Trainer" );
	addTradeSkill( "Elixir of Greater Water Breathing", 215, "Trainer" );
	addTradeSkill( "Wildvine Potion", 225, "Mob Drop.  Drops from trolls in Stranglethorn Vale and The Hinterlands" );
	addTradeSkill( "Philosopher's Stone", 225, "VENDOR" );
	addTradeSkill( "Transmute: Iron to Gold", 225, "VENDOR" );
	addTradeSkill( "Transmute: Mithril to Truesilver", 225, "VENDOR" );
	addTradeSkill( "Elixir of Detect Undead", 230, "Trainer" );
	addTradeSkill( "Dreamless Sleep Potion", 230, "Trainer" );
	addTradeSkill( "Arcane Elixir", 235, "Trainer" );
	addTradeSkill( "Invisibility Potion", 235, "World Drop (Buy on AH)" );
	addTradeSkill( "Elixir of Greater Intellect", 235, "Trainer" );
	addTradeSkill( "Gift of Arthas", 240, "Drops from some of the low level undead in Western Plaguelands" );
	addTradeSkill( "Elixir of Greater Agility", 240, "Trainer" );
	addTradeSkill( "Elixir of Dream Vision", 240, "World Drop (Buy on AH)" );
	addTradeSkill( "Elixir of Giants", 245, "World Drop (Buy on AH)" );
	addTradeSkill( "Ghost Dye", 245, "VENDOR" );
	addTradeSkill( "Elixir of Shadow Power", 250, "VENDOR" );
	addTradeSkill( "Elixir of Demonslaying", 250, "VENDOR" );
	addTradeSkill( "Elixir of Detect Demon", 250, "Trainer" );
	addTradeSkill( "Stonescale Oil", 250, "Trainer" );
	addTradeSkill( "Limited Invulnerability Potion", 250, "World Drop (Buy on AH)" );
	addTradeSkill( "Elixir of Greater Firepower", 250, "0.2-0.3% drop from Dark Iron Slavers, Dark Iron Taskmasters, and Dark Watchman in Searing Gorge.  No shame in buying it from the AH" );
	addTradeSkill( "Mighty Rage Potion", 255, "2% drop from Blackrock Slayers in Burning Steppes" );
	addTradeSkill( "Superior Mana Potion", 260, "VENDOR" );
	addTradeSkill( "Elixir of Superior Defense", 265, "VENDOR" );
	addTradeSkill( "Elixir of the Sages", 270, "Drops from some of the Scarlet guys in Easter Plaguelands (Archmages, Enchanters, Curates, Clerics, Inquisitors)" );
	addTradeSkill( "Transmute: Arcanite", 275, "VENDOR" );
	addTradeSkill( "Major Healing Potion", 275, "VENDOR" );
	addTradeSkill( "Elixir of Brute Force", 275, "Turn in Bloodpetal Sprouts for the Dadanga is Hungry quest in Un'Goro Crater.  You have about a 2% chance of getting this item.  You can also buy it on the AH" );
	addTradeSkill( "Transmute: Air to Fire", 275, "You can buy this from Argent Quartermasters when Honored with Argent Dawn" );
	addTradeSkill( "Transmute: Earth to Water", 275, "You can buy this from Meilosh in Felwood when you are Friendly with Timbermaw Hold." );
	addTradeSkill( "Transmute: Earth to Life", 275, "World Drop (Buy On AH)" );
	addTradeSkill( "Transmute: Fire to Earth", 275, "Bought from Plugger Spazzring in Blackrock Depths" );
	addTradeSkill( "Transmute: Undeath to Water", 275, "World Drop (Buy on AH)" );
	addTradeSkill( "Transmute: Water to Air", 275, "VENDOR" );
	addTradeSkill( "Transmute: Water to Undeath", 275, "World Drop (Buy on AH)" );
	addTradeSkill( "Transmute: Life to Earth", 275, "World Drop (Buy on AH)" );
	addTradeSkill( "Mageblood Potion", 275, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are Revered with Zandalar Tribe" );
	addTradeSkill( "Greater Dreamless Sleep Potion", 275, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are Friendly with Zandalar Tribe" );
	addTradeSkill( "Greater Stoneshield Potion", 280, "World Drop (Buy on AH)" );
	addTradeSkill( "Elixir of the Mongoose", 280, "Drops from Jadefire Rogues in Felwood and Legashi Rogues in Azshara" );
	addTradeSkill( "Purification Potion", 285, "World Drop (Buy on AH)" );
	addTradeSkill( "Greater Arcane Elixir", 285, "World Drop (Buy on AH)" );
	addTradeSkill( "Living Action Potion", 285, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are Exalted with Zandalar Tribe" );
	addTradeSkill( "Greater Stoneshield Potion", 280, "World Drop (Buy on AH)" );
	addTradeSkill( "Greater Fire Protection Potion", 290, "Drops from some Firebrand guys in Blackrock Spire (Invokers and Pyromancers), or Buy on AH" );
	addTradeSkill( "Greater Frost Protection Potion", 290, "2% drop from Frostmaul Giants in Winterspring" );
	addTradeSkill( "Greater Nature Protection Potion", 290, "1% drop from Rotting Behemoths and Decaying Horrors in Western Plagueland" );
	addTradeSkill( "Greater Arcane Protection Potion", 290, "2% drop from Cobalt Mageweavers in Winterspring" );
	addTradeSkill( "Greater Shadow Protection Potion", 290, "1% drop from Dark Adepts and Shadowmages in Eastern Plaguelands" );
	addTradeSkill( "Major Troll's Blood Potion", 290, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are Honored with Zandalar Tribe" );
	addTradeSkill( "Major Mana Potion", 295, "This one is a 6% BoP Drop from Darkmaster Gandling, the final boss of ScholomanceOr, you can do it the fun way.  With a Spectral Essence you can see Magnus Frostwake (Caer Darrow, Western Plagulands), who will sell you this recipe.  To get that item you need to complete the series of quests starting with Doctor Theolen Krastinov, The Butcher." );
	addTradeSkill( "Flask of Petrification", 300, "World Drop (Buy on AH)" );
	addTradeSkill( "Flask of the Titans", 300, "2% drop from General Drakkisath" );
	addTradeSkill( "Flask of Distilled Wisdom", 300, "2% drop from Balnazzar, the final boss in Scarlet/Live/West Stratholme" );
	addTradeSkill( "Flask of Supreme Power", 300, "2% drop from Ras Frostwhisper, an optional boss in Scholomance" );
	addTradeSkill( "Flask of Chromatic Resistance", 300, "3% drop from Gyth, Rend's pal in Upper Blackrock Spire" );
	addTradeSkill( "Major Rejuvenation Potion", 300, "Drops from MC Bosses" );
	addTradeSkill( "Transmute: Elemental Fire", 300, "Sold by Lokhtos Darkbargainer in Blackrock Depths to those Friendly with Thorium Brotherhood." );

	-- Burning Crusade Recipes
	addTradeSkill( "Adept's Elixir", 300, "Trainer" );
	addTradeSkill( "Onslaught Elixir", 300, "Trainer" );
	addTradeSkill( "Volatile Healing Potion", 300, "Trainer" );
	addTradeSkill( "Gurubashi Mojo Madness", 300, "You can learn this by clicking on a stone table in Zul'Gurub in the Edge of Madness" );
	addTradeSkill( "Elixir of Camouflage", 305, "Vendor Recipe (Limited Supply, the Grand Master Alchemists both sell it, among others)" );
	addTradeSkill( "Elixir of Major Strength", 305, "Trainer" );
	addTradeSkill( "Elixir of Healing Power", 310, "Trainer" );
	addTradeSkill( "Elixir of Major Fortitude", 310, "Trainer" );
	addTradeSkill( "Unstable Mana Potion", 310, "Trainer" );
	addTradeSkill( "Sneaking Potion", 315, "Vendor" );
	addTradeSkill( "Elixir of Mastery", 315, "Trainer" );
	addTradeSkill( "Elixir of Draenic Wisdom", 320, "Trainer" );
	addTradeSkill( "Elixir of Major Frost Power", 320, "Vendor" );
	addTradeSkill( "Insane Strength Potion", 320, "World Drop (Buy on AH)" );
	addTradeSkill( "Earthen Elixir", 320, "You can buy this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Elixir of the Searching Eye", 325, "World Drop (Buy on AH)" );
	addTradeSkill( "Mercurial Stone", 325, "Trainer" );
	addTradeSkill( "Super Healing Potion", 325, "Trainer" );
	addTradeSkill( "Elixir of Major Agility", 330, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are honored with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are honored with Thrallmar" );
	addTradeSkill( "Elixir of Ironskin", 330, "Alliance can buy this from Quartermaster Davian Vaclav, Horde from Quartermaster Jaffrey Noreliqe in Halaa for 2 Halaa Research Tokens." );
	addTradeSkill( "Shrouding Potion", 335, "You can buy this from Mycah in Zangarmarsh when you are Exalted with Sporeggar" );
	addTradeSkill( "Fel Strength Elixir", 335, "BoP drop from Mo'arg Weaponsmiths, Terrormasters, Wrathwalkers, and Shadow Council Warlocks in Shadowmoon Valley.  Only drops for alchemists, so drop rates should be higher than they seem on thott et al" );
	addTradeSkill( "Super Mana Potion", 340, "Vendor" );
	addTradeSkill( "Elixir of Major Firepower", 345, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Elixir of Major Defense", 345, "Vendor" );
	addTradeSkill( "Fel Regeneration Potion", 345, "BoP drop from Deathforge guys in Shadowmoon Valley (Guardians, Imps, Smiths, Tinkerers.  Only drops for alchemists, so drop rates should be higher than they seem on thott et al" );
	addTradeSkill( "Elixir of Major Shadow Power", 350, "You can buy this from Nakodu in Shattrath City when you are revered with Lower City" );
	addTradeSkill( "Major Dreamless Sleep Potion", 350, "Vendor" );
	addTradeSkill( "Heroic Potion", 350, "World Drop (Buy on AH)" );
	addTradeSkill( "Haste Potion", 350, "World Drop (Buy on AH)" );
	addTradeSkill( "Destruction Potion", 350, "World Drop (Buy on AH)" );
	addTradeSkill( "Transmute: Primal Air to Fire", 350, "You can buy this from Almaador in Shattrath City when you are revered with The Sha'tar" );
	addTradeSkill( "Transmute: Primal Earth to Water", 350, "You can buy this from Mycah in Zangarmarsh when you are revered with Sporeggar" );
	addTradeSkill( "Transmute: Primal Fire to Earth", 350, "Alliance can buy this from Trader Narasu in Nagrand when they are revered with Kurenai, Horde from Provisioner Nasala when they are revered with Mag'har" );
	addTradeSkill( "Transmute: Primal Water to Air", 350, "You can buy this from Fedryen Swiftspear in Zangarmarsh when you are revered with Cenarion Expedition" );
	addTradeSkill( "Transmute: Primal Might", 350, "Limited-Supply Vendor Recipe" );
	addTradeSkill( "Transmute: Earthstorm Diamond", 350, "You can buy this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Transmute: Skyfire Diamond", 350, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are honored with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are honored with Thrallmar" );
	addTradeSkill( "Alchemist's Stone", 350, "Trainer" );
	addTradeSkill( "Elixir of Major Mageblood", 355, "World Drop (Buy on AH)" );
	addTradeSkill( "Major Arcane Protection Potion", 360, "BoP mob drop from Vir'aani Arcanists in Nagrand.  Only drops for alchemists, so drop rates should be higher than they seem on thott et al." );
	addTradeSkill( "Major Fire Protection Potion", 360, "BoP mob drop from Sunseeker Astromages in The Mechanar.  Only drops for alchemists, so drop rates should be higher than they seem on thott et al." );
	addTradeSkill( "Major Frost Protection Potion", 360, "BoP mob drop from Nexus-Prince Shaffar, the final boss in Mana Tombs.  Only drops for alchemists, so drop rates should be higher than they seem on thott et al." );
	addTradeSkill( "Major Holy Protection Potion", 360, "BoP mob drop from Abyssal Flamebringers in Blade's Edge.  Only drops for alchemists, so drop rates should be higher than they seem on thott et al." );
	addTradeSkill( "Major Nature Protection Potion", 360, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are exalted with Cenarion Expedition" );
	addTradeSkill( "Major Shadow Protection Potion", 360, "BoP mob drop from Shadow Council Warlock.  Only drops for alchemists, so drop rates should be higher than they seem on thott et al." );
	addTradeSkill( "Fel Mana Potion", 360, "BoP mob drop from Eclipsion guys in Shadowmoon Valley.  Only drops for alchemists, so drop rates should be higher than they seem on thott et al." );
	addTradeSkill( "Elixir of Empowerment", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Ironshield Potion", 365, "BoP Mob drop from Captain Skarloc in Old Hillsbrad Foothills.  Only drops for alchemists, so drop rates should be higher than they seem on thott et al." );

	-- Burning Crusade Discovery Recipes
	addTradeSkill( "Transmute: Primal Life to Earth", 350, "Discovery" );
	addTradeSkill( "Transmute: Primal Earth to Life", 350, "Discovery" );
	addTradeSkill( "Transmute: Primal Mana to Fire", 350, "Discovery" );
	addTradeSkill( "Transmute: Primal Water to Shadow", 350, "Discovery" );
	addTradeSkill( "Flask of Fortification", 375, "Discovery" );
	addTradeSkill( "Flask of Mighty Restoration", 375, "Discovery" );
	addTradeSkill( "Flask of Relentless Assault", 375, "Discovery" );
	addTradeSkill( "Flask of Arcane Fortification", 375, "Discovery" );
	addTradeSkill( "Flask of Shadow Fortification", 375, "Discovery" );	
	addTradeSkill( "Super Rejuvenation Potion", 375, "Discovery" );
	addTradeSkill( "Cauldron of Major Arcane Protection", 375, "Discovered when making Major Arcane Protection Potion" );
	addTradeSkill( "Cauldron of Major Fire Protection", 375, "Discovered when making Major Fire Protection Potion" );
	addTradeSkill( "Cauldron of Major Frost Protection", 375, "Discovered when making Major Frost Protection Potion" );
	addTradeSkill( "Cauldron of Major Nature Protection", 375, "Discovered when making Major Nature Protection Potion" );
	addTradeSkill( "Cauldron of Major Shadow Protection", 375, "Discovered when making Major Shadow Protection Potion" );

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all Beast Training Abilities.  As of 2.2 there are

function AckisRecipeList:InitBeastTraining()

	AckisRecipeList.InitializeRecipeArray();

	addTradeSkill( "Great Stamina (Rank 1)", 10, "Trainer" );
	addTradeSkill( "Great Stamina (Rank 2)", 12, "Trainer" );
	addTradeSkill( "Great Stamina (Rank 3)", 18, "Trainer" );
	addTradeSkill( "Great Stamina (Rank 4)", 24, "Trainer" );
	addTradeSkill( "Great Stamina (Rank 5)", 30, "Trainer" );
	addTradeSkill( "Great Stamina (Rank 6)", 36, "Trainer" );
	addTradeSkill( "Great Stamina (Rank 7)", 42, "Trainer" );
	addTradeSkill( "Great Stamina (Rank 8)", 48, "Trainer" );
	addTradeSkill( "Great Stamina (Rank 9)", 54, "Trainer" );
	addTradeSkill( "Great Stamina (Rank 10)", 60, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 1)", 10, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 2)", 12, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 3)", 18, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 4)", 24, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 5)", 30, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 6)", 36, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 7)", 42, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 8)", 48, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 9)", 54, "Trainer" );
	addTradeSkill( "Natural Armor (Rank 10)", 60, "Trainer" );
	addTradeSkill( "Arcane Resistance (Rank 1)", 20, "Trainer" );
	addTradeSkill( "Arcane Resistance (Rank 2)", 30, "Trainer" );
	addTradeSkill( "Arcane Resistance (Rank 3)", 40, "Trainer" );
	addTradeSkill( "Arcane Resistance (Rank 4)", 50, "Trainer" );
	addTradeSkill( "Arcane Resistance (Rank 5)", 60, "Trainer" );
	addTradeSkill( "Fire Resistance (Rank 1)", 20, "Trainer" );
	addTradeSkill( "Fire Resistance (Rank 2)", 30, "Trainer" );
	addTradeSkill( "Fire Resistance (Rank 3)", 40, "Trainer" );
	addTradeSkill( "Fire Resistance (Rank 4)", 50, "Trainer" );
	addTradeSkill( "Fire Resistance (Rank 5)", 60, "Trainer" );
	addTradeSkill( "Frost Resistance (Rank 1)", 20, "Trainer" );
	addTradeSkill( "Frost Resistance (Rank 2)", 30, "Trainer" );
	addTradeSkill( "Frost Resistance (Rank 3)", 40, "Trainer" );
	addTradeSkill( "Frost Resistance (Rank 4)", 50, "Trainer" );
	addTradeSkill( "Frost Resistance (Rank 5)", 60, "Trainer" );
	addTradeSkill( "Nature Resistance (Rank 1)", 20, "Trainer" );
	addTradeSkill( "Nature Resistance (Rank 2)", 30, "Trainer" );
	addTradeSkill( "Nature Resistance (Rank 3)", 40, "Trainer" );
	addTradeSkill( "Nature Resistance (Rank 4)", 50, "Trainer" );
	addTradeSkill( "Nature Resistance (Rank 5)", 60, "Trainer" );
	addTradeSkill( "Shadow Resistance (Rank 1)", 20, "Trainer" );
	addTradeSkill( "Shadow Resistance (Rank 2)", 30, "Trainer" );
	addTradeSkill( "Shadow Resistance (Rank 3)", 40, "Trainer" );
	addTradeSkill( "Shadow Resistance (Rank 4)", 50, "Trainer" );
	addTradeSkill( "Shadow Resistance (Rank 5)", 60, "Trainer" );
	addTradeSkill( "Growl (Rank 1)", 10 );
	addTradeSkill( "Growl (Rank 2)", 10 );
	addTradeSkill( "Growl (Rank 3)", 20 );
	addTradeSkill( "Growl (Rank 4)", 30 );
	addTradeSkill( "Growl (Rank 5)", 40 );
	addTradeSkill( "Growl (Rank 6)", 50 );
	addTradeSkill( "Growl (Rank 7)", 60 );
	addTradeSkill( "Bite (Rank 1)", 10 );
	addTradeSkill( "Bite (Rank 2)", 10 );
	addTradeSkill( "Bite (Rank 3)", 16 );
	addTradeSkill( "Bite (Rank 4)", 24 );
	addTradeSkill( "Bite (Rank 5)", 32 );
	addTradeSkill( "Bite (Rank 6)", 40 );
	addTradeSkill( "Bite (Rank 7)", 48 );
	addTradeSkill( "Bite (Rank 8)", 56 );
	addTradeSkill( "Claw (Rank 1)", 10 );
	addTradeSkill( "Claw (Rank 2)", 10 );
	addTradeSkill( "Claw (Rank 3)", 16 );
	addTradeSkill( "Claw (Rank 4)", 24 );
	addTradeSkill( "Claw (Rank 5)", 32 );
	addTradeSkill( "Claw (Rank 6)", 40 );
	addTradeSkill( "Claw (Rank 7)", 48 );
	addTradeSkill( "Claw (Rank 8)", 56 );
	addTradeSkill( "Cower (Rank 1)", 10 );
	addTradeSkill( "Cower (Rank 2)", 15 );
	addTradeSkill( "Cower (Rank 3)", 25 );
	addTradeSkill( "Cower (Rank 4)", 35 );
	addTradeSkill( "Cower (Rank 5)", 45 );
	addTradeSkill( "Cower (Rank 6)", 55 );
	addTradeSkill( "Dash (Rank 1)", 30 );
	addTradeSkill( "Dash (Rank 2)", 40 );
	addTradeSkill( "Dash (Rank 3)", 50 );
	addTradeSkill( "Dive (Rank 1)", 30 );
	addTradeSkill( "Dive (Rank 2)", 40 );
	addTradeSkill( "Dive (Rank 3)", 50 );
	addTradeSkill( "Furious Howl (Rank 1)", 10 );
	addTradeSkill( "Furious Howl (Rank 2)", 24 );
	addTradeSkill( "Furious Howl (Rank 3)", 40 );
	addTradeSkill( "Furious Howl (Rank 4)", 56 );
	addTradeSkill( "Screech (Rank 1)", 10 );
	addTradeSkill( "Screech (Rank 2)", 24 );
	addTradeSkill( "Screech (Rank 3)", 40 );
	addTradeSkill( "Screech (Rank 4)", 56 );
	--addTrade( "Lightning Breath (Rank 1)", 10 ) There is no Rank 1 Lightning Breath
	addTradeSkill( "Lightning Breath (Rank 2)", 12 );
	addTradeSkill( "Lightning Breath (Rank 3)", 24 );
	addTradeSkill( "Lightning Breath (Rank 4)", 36 );
	addTradeSkill( "Lightning Breath (Rank 5)", 48 );
	addTradeSkill( "Lightning Breath (Rank 6)", 60 );
	addTradeSkill( "Scorpid Poison (Rank 1)", 10 );
	addTradeSkill( "Scorpid Poison (Rank 2)", 24 );
	addTradeSkill( "Scorpid Poison (Rank 3)", 40 );
	addTradeSkill( "Scorpid Poison (Rank 4)", 56 );
	addTradeSkill( "Prowl (Rank 1)", 30 );
	addTradeSkill( "Prowl (Rank 2)", 40 );
	addTradeSkill( "Prowl (Rank 3)", 50 );
	addTradeSkill( "Charge (Rank 1)", 10 );
	addTradeSkill( "Charge (Rank 2)", 12 );
	addTradeSkill( "Charge (Rank 3)", 24 );
	--addTrade( "Charge (Rank 4)", XX ); There is no Rank 4 Charge!
	addTradeSkill( "Charge (Rank 5)", 42 );
	addTradeSkill( "Charge (Rank 6)", 60 );
	addTradeSkill( "Shell Shield (Rank 1)", 20 );
	addTradeSkill( "Thunderstomp (Rank 1)", 30 );
	addTradeSkill( "Thunderstomp (Rank 2)", 40 );
	addTradeSkill( "Thunderstomp (Rank 3)", 50 );
	
end

-- Initializes the array adding all Blacksmithing recipes.  As of 2.2 there are

function AckisRecipeList:InitBlackSmith()

	AckisRecipeList.InitializeRecipeArray();

	addTradeSkill( "Rough Sharpening Stone", 1, "Trainer" );
	addTradeSkill( "Copper Bracers", 1, "Trainer" );
	addTradeSkill( "Rough Copper Vest", 1, "Trainer" );
	addTradeSkill( "Copper Chain Pants", 1, "Trainer" );
	addTradeSkill( "Copper Mace", 15, "Trainer" );
	addTradeSkill( "Copper Chain Boots", 20, "Trainer" );
	addTradeSkill( "Copper Axe", 20, "Trainer" );
	addTradeSkill( "Rough Weightstone", 25, "Trainer" );
	addTradeSkill( "Rough Grinding Stone", 25, "Trainer" );
	addTradeSkill( "Copper Shortsword", 25, "Trainer" );
	addTradeSkill( "Copper Dagger", 30, "Trainer" );
	addTradeSkill( "Copper Claymore", 30, "Trainer" );
	addTradeSkill( "Copper Battle Axe", 35, "Trainer" );
	addTradeSkill( "Copper Chain Vest", 35, "World Drop (Buy on AH) or alliance blacksmithing quest that totally isn't worth it" );
	addTradeSkill( "Copper Chain Belt", 35, "Trainer" );
	addTradeSkill( "Runed Copper Gauntlets", 40, "Trainer" );
	addTradeSkill( "Runed Copper Pants", 45, "Trainer" );
	addTradeSkill( "Gemmed Copper Gauntlets", 60, "World Drop (Buy on AH)" );
	addTradeSkill( "Coarse Weightstone", 65, "Trainer" );
	addTradeSkill( "Heavy Copper Maul", 65, "Trainer" );
	addTradeSkill( "Coarse Sharpening Stone", 65, "Trainer" );
	addTradeSkill( "Coarse Grinding Stone", 75, "Trainer" );
	addTradeSkill( "Runed Copper Breastplate", 80, "World Drop (Buy on AH)" );
	addTradeSkill( "Runed Copper Bracers", 90, "Trainer" );
	addTradeSkill( "Thick War Axe", 90, "Trainer" );
	addTradeSkill( "Runed Copper Belt", 90, "Trainer" );
	addTradeSkill( "Heavy Copper Broadsword", 95, "Trainer" );
	addTradeSkill( "Rough Bronze Boots", 95, "Trainer" );
	addTradeSkill( "Big Bronze Knife", 100, "Trainer" );
	addTradeSkill( "Silver Rod", 100, "Trainer" );
	addTradeSkill( "Ironforge Breastplate", 100, "From Alliance Quest Gearing Redridge", "Alliance");
	addTradeSkill( "Silver Skeleton Key", 100, "Trainer" );
	addTradeSkill( "Thick Bronze Darts", 100, "Unknown");
	addTradeSkill( "Rough Bronze Leggings", 105, "Trainer" );
	addTradeSkill( "Rough Bronze Cuirass", 105, "Trainer" );
	addTradeSkill( "Rough Bronze Shoulders", 110, "Trainer" );
	addTradeSkill( "Bronze Mace", 110, "Trainer" );
	addTradeSkill( "Pearl-handled Dagger", 115, "Trainer" );
	addTradeSkill( "Bronze Axe", 115, "Trainer" );
	addTradeSkill( "Bronze Shortsword", 120, "Trainer" );
	addTradeSkill( "Patterned Bronze Bracers", 120, "Trainer" );
	addTradeSkill( "Heavy Weightstone", 125, "Trainer" );
	addTradeSkill( "Deadly Bronze Poniard", 125, "World Drop (Buy on AH)" );
	addTradeSkill( "Silvered Bronze Shoulders", 125, "World Drop (Buy on AH)" );
	addTradeSkill( "Heavy Grinding Stone", 125, "Trainer" );
	addTradeSkill( "Bronze Warhammer", 125, "Trainer" );
	addTradeSkill( "Heavy Sharpening Stone", 125, "Trainer" );
	addTradeSkill( "Heavy Bronze Mace", 130, "Trainer" );
	addTradeSkill( "Silvered Bronze Boots", 130, "Trainer" );
	addTradeSkill( "Silvered Bronze Breastplate", 130, "World Drop (Buy on AH)" );
	addTradeSkill( "Bronze Greatsword", 130, "Trainer" );
	addTradeSkill( "Silvered Bronze Gauntlets", 135, "Trainer" );
	addTradeSkill( "Bronze Battle Axe", 135, "Trainer" );
	addTradeSkill( "Iridescent Hammer", 140, "World Drop (Buy on AH)" );
	addTradeSkill( "Mighty Iron Hammer", 145, "World Drop (Buy on AH)" );
	addTradeSkill( "Green Iron Boots", 145, "World Drop (Buy on AH)" );
	addTradeSkill( "Shining Silver Breastplate", 145, "Trainer" );
	addTradeSkill( "Green Iron Gauntlets", 150, "World Drop (Buy on AH)" );
	addTradeSkill( "Iron Shield Spike", 150, "World Drop (Buy on AH)" );
	addTradeSkill( "Iron Buckle", 150, "Trainer" );
	addTradeSkill( "Golden Rod", 150, "Trainer" );
	addTradeSkill( "Golden Skeleton Key", 150, "Trainer" );
	addTradeSkill( "Solid Iron Maul", 155, "VENDOR" );
	addTradeSkill( "Green Iron Leggings", 155, "Trainer" );
	addTradeSkill( "Silvered Bronze Leggings", 155, "World Drop (Buy on AH)" );
	addTradeSkill( "Hardened Iron Shortsword", 160, "VENDOR" );
	addTradeSkill( "Green Iron Shoulders", 160, "World Drop (Buy on AH)" );
	addTradeSkill( "Barbaric Iron Shoulders", 160, "Quest reward from Horde Quest On Iron Pauldroms from Omokk Omosh (Orgrimmar)", "Horde" );
	addTradeSkill( "Barbaric Iron Breastplate", 160, "Quest reward from Horde Quest Barbaric Battlements from Omokk Omosh (Orgrimmar)", "Horde" );
	addTradeSkill( "Green Iron Bracers", 165, "Trainer" );
	addTradeSkill( "Iron Counterweight", 165, "World Drop (Buy on AH)" );
	addTradeSkill( "Golden Iron Destroyer", 170, "World Drop (Buy on AH)" );
	addTradeSkill( "Green Iron Helm", 170, "Trainer" );
	addTradeSkill( "Golden Scale Leggings", 170, "World Drop (Buy on AH)" );
	addTradeSkill( "Jade Serpentblade", 175, "World Drop (Buy on AH)" );
	addTradeSkill( "Golden Scale Shoulders", 175, "World Drop (Buy on AH)" );
	addTradeSkill( "Barbaric Iron Helm", 175, "Reward from Horns of Frenzy, a Horde quest from Orokk Omosh (Orgrimmar)", "Horde" );
	addTradeSkill( "Moonsteel Broadsword", 180, "VENDOR" );
	addTradeSkill( "Green Iron Hauberk", 180, "Trainer" );
	addTradeSkill( "Barbaric Iron Boots", 180, "Reward from Trampled Under Foot, a Horde quest from Orokk Omosh (Orgrimmar)", "Horde" );
	addTradeSkill( "Glinting Steel Dagger", 180, "Trainer" );
	addTradeSkill( "Massive Iron Axe", 185, "VENDOR" );
	addTradeSkill( "Polished Steel Boots", 185, "World Drop (Buy on AH)" );
	addTradeSkill( "Golden Scale Bracers", 185, "Trainer" );
	addTradeSkill( "Barbaric Iron Gloves", 185, "Quest reward from Horde Quest Joys of Omosh given by Omokk Omosh (Orgrimmar)", "Horde" );
	addTradeSkill( "Golden Scale Coif", 190, "VENDOR" );
	addTradeSkill( "Steel Weapon Chain", 190, "World Drop (Buy on AH)" );
	addTradeSkill( "Searing Golden Blade", 190, "World Drop (Buy on AH)" );
	addTradeSkill( "Edge of Winter", 190, "This is one of the rewards from the Christmas quests" );
	addTradeSkill( "Golden Scale Cuirass", 195, "World Drop (Buy on AH)" );
	addTradeSkill( "Frost Tiger Blade", 200, "World Drop (Buy on AH)" );
	addTradeSkill( "Shadow Crescent Axe", 200, "World Drop (Buy on AH)" );
	addTradeSkill( "Golden Scale Boots", 200, "World Drop (Buy on AH)" );
	addTradeSkill( "Steel Breastplate", 200, "Trainer" );
	addTradeSkill( "Solid Sharpening Stone", 200, "Trainer" );
	addTradeSkill( "Solid Weightstone", 200, "Trainer" );
	addTradeSkill( "Solid Grinding Stone", 200, "Trainer" );
	addTradeSkill( "Inlaid Mithril Cylinder", 200, "This recipe is made by Gnomish Engineers" );
	addTradeSkill( "Truesilver Rod", 200, "Trainer" );
	addTradeSkill( "Truesilver Skeleton Key", 200, "Trainer" );
	addTradeSkill( "Whirling Steel Axes", 200, nil );
	addTradeSkill( "Heavy Mithril Shoulder", 205, "Trainer" );
	addTradeSkill( "Heavy Mithril Gauntlet", 205, "Trainer" );
	addTradeSkill( "Golden Scale Gauntlets", 205, "Reward from Alliance Quest The Origins of Smithing from Hank the Hammer (Stormwind City)", "Alliance" );
	addTradeSkill( "Mithril Scale Pants", 210, "Trainer" );
	addTradeSkill( "Heavy Mithril Pants", 210, "World Drop (Buy on AH)" );
	addTradeSkill( "Heavy Mithril Axe", 210, "Trainer" );
	addTradeSkill( "Steel Plate Helm", 215, "Trainer" );
	addTradeSkill( "Mithril Scale Bracers", 215, "VENDOR" );
	addTradeSkill( "Mithril Shield Spike", 215, "World Drop (Buy on AH)" );
	addTradeSkill( "Ornate Mithril Pants", 220, "Quest reward from Smelt On, Smelt Off from Galvan the Ancient (Stranglethorn Vale)" );
	addTradeSkill( "Ornate Mithril Gloves", 220, "Reward from the quest The Great Silver Deceiver from Galvan the Ancient (Stranglethorn Vale)" );
	addTradeSkill( "Blue Glittering Axe", 220, "World Drop (Buy on AH)" );
	addTradeSkill( "Ornate Mithril Shoulder", 225, "Reward from quest The Art of the Imbue from Galvan the Ancient (Stranglethorn Vale)" );
	addTradeSkill( "Wicked Mithril Blade", 225, "World Drop (Buy on AH)" );
	addTradeSkill( "Heavy Mithril Breastplate", 230, "Trainer" );
	addTradeSkill( "Mithril Coif", 230, "Trainer" );
	addTradeSkill( "Big Black Mace", 230, "Trainer" );
	addTradeSkill( "Mithril Spurs", 235, "World Drop (Buy on AH)" );
	addTradeSkill( "Mithril Scale Shoulders", 235, "World Drop (Buy on AH)" );
	addTradeSkill( "Heavy Mithril Boots", 235, "Trainer" );
	addTradeSkill( "Ornate Mithril Breastplate", 235, "Trainer" );
	addTradeSkill( "Ornate Mithril Boots", 240, "Trainer" );
	addTradeSkill( "Dazzling Mithril Rapier", 240, "World Drop (Buy on AH)" );
	addTradeSkill( "Heavy Mithril Helm", 245, "World Drop (Buy on AH)" );
	addTradeSkill( "Ornate Mithril Helm", 245, "Reward from the quest A Good Head on Your Shoulders from Trenton Lighthammer (Tanaris).  You need to do to do the Galvan the Ancient quests first." );
	addTradeSkill( "Runed Mithril Hammer", 245, "World Drop (Buy on AH)" );
	addTradeSkill( "Dense Sharpening Stone", 250, "Trainer" );
	addTradeSkill( "Dense Weightstone", 250, "Trainer" );
	addTradeSkill( "Dense Grinding Stone", 250, "Trainer" );
	addTradeSkill( "Thorium Armor", 250, "World Drop (Buy on AH)" );
	addTradeSkill( "Thorium Belt", 250, "World Drop (Buy on AH)" );
	addTradeSkill( "Orcish War Leggings", 250, "If anybody knows how they got this, let me (the mod author) know.  I'm surmising it is trained (there are no plans, since I can't find records of them) after you do the horde blacksmithing quest The Old Ways", "Horde" );
	addTradeSkill( "Ebon Shiv", 255, "VENDOR" );
	addTradeSkill( "Thorium Bracers", 255, "World Drop (Buy on AH)" );
	addTradeSkill( "Radiant Belt", 260, "World Drop (Buy on AH)" );
	addTradeSkill( "Imperial Plate Shoulders", 265, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Imperial Plate Belt", 265, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Dark Iron Mail", 270, "These can drop from Blacksmith Plans (scrolls you can click) in BRD.  Also (allegedly) an incredibly rare drop (less than 00.01%) from certain mobs in BRD/BRM" );
	addTradeSkill( "Radiant Breastplate", 270, "World Drop (Buy on AH)" );
	addTradeSkill( "Imperial Plate Bracers", 270, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Thorium Shield Spike", 275, "World Drop (Buy on AH)" );
	addTradeSkill( "Ornate Thorium Handaxe", 275, "VENDOR" );
	addTradeSkill( "Arcanite Skeleton Key", 275, "Trainer" );
	addTradeSkill( "Arcanite Rod", 275, "Trainer" );
	addTradeSkill( "Dark Iron Shoulders", 280, "These can drop from Blacksmith Plans (scrolls you can click) in BRD.  Also (allegedly) an incredibly rare drop (less than 00.01%) from certain mobs in BRD/BRM" );
	addTradeSkill( "Thorium Boots", 280, "World Drop (Buy on AH)" );
	addTradeSkill( "Thorium Helm", 280, "World Drop (Buy on AH)" );
	addTradeSkill( "Huge Thorium Battleaxe", 280, "VENDOR" );
	addTradeSkill( "Radiant Gloves", 285, "World Drop (Buy on AH)" );
	addTradeSkill( "Radiant Boots", 290, "World Drop (Buy on AH)" );
	addTradeSkill( "Volcanic Hammer", 290, "Frequent drop from Volchan, that big elite guy that wanders around Burning Steppes" );
	addTradeSkill( "Heavy Timbermaw Belt", 290, "You can buy this from Meilosh in Felwood when you are Honored with Timbermaw Furbolgs" );
	addTradeSkill( "Girdle of the Dawn", 290, "You can buy this from an Argent Quartermaster when you are Honored with Argent Dawn" );
	addTradeSkill( "Imperial Plate Boots", 295, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Imperial Plate Helm", 295, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Radiant Circlet", 295, "World Drop (Buy on AH)" );
	addTradeSkill( "Thorium Leggings", 300, "World Drop (Buy on AH)" );
	addTradeSkill( "Imperial Plate Chest", 300, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Runic Plate Shoulders", 300, "Mob Drop: from Strashaz Serpent Guards in Dustwallow Marsh (Alcaz Island)" );
	addTradeSkill( "Runic Plate Boots", 300, "Mob Drop: from Scarlet Cavaliers in Western Plaguelands (Hearthglen" );
	addTradeSkill( "Radiant Leggings", 300, "World Drop (Buy on AH)" );
	addTradeSkill( "Runic Plate Helm", 300, "Mob Drop: from Strashaz Warriors in Dustwallow Marsh (Alcaz Island)" );
	addTradeSkill( "Imperial Plate Leggings", 300, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Runic Breastplate", 300, "Mob Drop: from Strashaz Myrmidons in Dustwallow Marsh (Alcaz Island)" );
	addTradeSkill( "Runic Plate Leggings", 300, "Mob Drop: from Scarlet Smiths in Western Plaguelands (Hearthglen)" );
	addTradeSkill( "Sulfuron Hammer", 300, "Reward from the quest 'A Binding Contract' from Lokhtos Darkbargainer in BRD.  Oh, you'll need to give him a Sulfuron Ingot to complete the quest" );
	addTradeSkill( "Elemental Sharpening Stone", 300, "BoP Drop from certain Molten Core bosses" );
	addTradeSkill( "Heavy Timbermaw Boots", 300, "You can buy this from Meilosh in Felwood when you are honored with Timbermaw Furbolgs" );
	addTradeSkill( "Gloves of the Dawn", 300, "You can buy this from an Argent Quartermaster when you are revered with Argent Dawn" );
	addTradeSkill( "Bloodsoul Breastplate", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Bloodsoul Gauntlets", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are friendly with Zandalar Tribe" );
	addTradeSkill( "Bloodsoul Shoulders", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Darksoul Breastplate", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Darksoul Leggings", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Darksoul Shoulders", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are friendly with Zandalar Tribe" );
	addTradeSkill( "Darkrune Breastplate", 300, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)"  );
	addTradeSkill( "Darkrune Gauntlets", 300, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Darkrune Helm", 300, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Heavy Obsidian Belt", 300, "Sold by Vargus in Cenarion Hold when you are friendly with Cenarion Circle" );
	addTradeSkill( "Light Obsidian Belt", 300, "Sold by Vargus in Cenarion Hold when you are honored with Cenarion Circle" );
	addTradeSkill( "Jagged Obsidian Shield", 300, "Sold by Vargus in Cenarion Hold when you are revered with Cenarion Circle" );
	addTradeSkill( "Black Grasp of the Destroyer", 300, "7% drop from Moam in AQ20" );
	addTradeSkill( "Obsidian Mail Tunic", 300, "Sold by Vargus in Cenarion Hold when you are exalted with Cenarion Circle" );
	addTradeSkill( "Thick Obsidian Breastplate", 300, "6% drop from The Prophet Skeram in AQ40" );
	addTradeSkill( "Ironvine Breastplate", 300, "Sold by Vargus in Cenarion Hold when you are revered with Cenarion Circle" );
	addTradeSkill( "Ironvine Gloves", 300, "Sold by Vargus in Cenarion Hold when you are honored with Cenarion Circle" );
	addTradeSkill( "Ironvine Belt", 300, "Sold by Vargus in Cenarion Hold when you are friendly with Cenarion Circle" );
	addTradeSkill( "Enchanted Thorium Blades", 300, "Trainer" );

	addTradeSkill( "The Shatterer", 235 , "Trainer" );
	addTradeSkill( "Phantom Blade", 245, "Trainer" );
	addTradeSkill( "Blight", 250, "Trainer" );

	addTradeSkill( "Truesilver Champion", 260, "Trainer" );
	addTradeSkill( "Earthforged Leggings", 260, "Armorsmith", "Trainer" );
	addTradeSkill( "Windforged Leggings", 260, "Armorsmith", "Trainer" );
	addTradeSkill( "Light Earthforged Blade", 260, "Weaponsmith", "Trainer" );
	addTradeSkill( "Light Emberforged Hammer", 260, "Weaponsmith", "Trainer" );
	addTradeSkill( "Light Skyforged Axe", 260, "Weaponsmith", "Trainer" );

	addTradeSkill( "Dark Iron Pulverizer", 265, "Weaponsmith", "Drops from Grizzle in BRD" ); -- specialty is probably a bliz mistake, might get fixed some day
	addTradeSkill( "Dark Iron Sunderer", 275, "Drops from Hammered Patrons or Ribbly's Crony in BRD" );
	addTradeSkill( "Heartseeker", 300, "Drops from Cannon Master Willey in Stratholme" );
	addTradeSkill( "Black Amnesty", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Blackfury", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are revered with Thorium Brotherhood" );
  
	addTradeSkill( "Truesilver Gauntlets", 225, "Trainer" );
	addTradeSkill( "Truesilver Breastplate", 245, "Trainer" );
	addTradeSkill( "Wildthorn Mail", 270, "World Drop (Buy on AH)" );
	addTradeSkill( "Dark Iron Plate", 285, "Drops from Ribbly Screwspigot in BRD" );
	addTradeSkill( "Demon Forged Breastplate", 285, "Reward from the quest 'The Demon Forge' given by Lorax in Winterspring.  It requires that you kill a mob in UBRS, and there might be prereqs that I am unaware of"  );
	addTradeSkill( "Fiery Plate Gauntlets", 290, "Reward from the quest 'Fiery Plate Gauntlets'" );
	addTradeSkill( "Dawnbringer Shoulders", 290, "World Drop (Buy on AH)" );
	addTradeSkill( "Storm Gauntlets", 295, "VENDOR" );
	addTradeSkill( "Dark Iron Bracers", 295, "You can buy this from Lokhtos Darkbargainer in BRD when you are friendly with Thorium Brotherhood" );
	addTradeSkill( "Fiery Chain Girdle", 295, "You can buy this from Lokhtos Darkbargainer in BRD when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Whitesoul Helm", 300, "World Drop (Buy on AH)" );
	addTradeSkill( "Helm of the Great Chief", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );
	addTradeSkill( "Lionheart Helm", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)");
	addTradeSkill( "Stronghold Gauntlets", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );
	addTradeSkill( "Enchanted Thorium Helm", 300, "Turn in Enchanted Thorium Platemail Vol III (Top and bottom halves) to Athaeneum in the DM Library" );
	addTradeSkill( "Enchanted Thorium Leggings", 300, "Turn in Enchanted Thorium Platemail Vol II (Top and bottom halves) to Athaeneum in the DM Library" );
	addTradeSkill( "Enchanted Thorium Breastplate", 300, "Turn in Enchanted Thorium Platemail Vol I (Top and bottom halves) to Athaeneum in the DM Library" );
	addTradeSkill( "Invulnerable Mail", 300, "1% drop from Goraluk Anvilcrack in UBRS, also a world drop from high-level (60+) mobs pre-TBC" );
	addTradeSkill( "Dark Iron Leggings", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );
	addTradeSkill( "Fiery Chain Shoulders", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Dark Iron Helm", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Dark Iron Gauntlets", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Dark Iron Boots", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );
	addTradeSkill( "Titanic Leggings", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );

	addTradeSkill( "Blazing Rapier", 280, "A reward from the Corruption quest given in Everlook (Winterspring)" );
	addTradeSkill( "Corruption", 290, "These can drop from Blacksmith Plans (scrolls you can click) in Stratholme.  Also (allegedly) an incredibly rare drop ( 0.2% and less, depending on the mob) from certain undead guys in Stratholme" );
	addTradeSkill( "Arcanite Champion", 300, "5% drop from Goraluk Anvilcrack in UBRS" );
	addTradeSkill( "Frostguard", 300, "Drops from rare spawn Foreman Marcrid in WPL, roundabouts the lumber mill.  High frequency of getting this drop (85%+"  );
	addTradeSkill( "Dark Iron Reaver", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Blackguard", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );
	addTradeSkill( "Sageblade", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );

	addTradeSkill( "Enchanted Battlehammer", 280, "Quest reward from 'Sweet Serenity', given by Lilith the Lithe in Everlook (Winterspring)" );
	addTradeSkill( "Serenity", 285, "These can drop from Blacksmith Plans (scrolls you can click) in Stratholme.  Also (allegedly) an incredibly rare drop ( 0.2% and less, depending on the mob) from certain Crimson guys in Stratholme" );
	addTradeSkill( "Hammer of the Titans", 300, "6% drop from Maleki the Pallid in Stratholme" );
	addTradeSkill( "Masterwork Stormhammer", 300, "5% drop from Goraluk Anvilcrack in UBRS" );
	addTradeSkill( "Ebon Hand", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );
	addTradeSkill( "Persuader", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );

	addTradeSkill( "Dawn's Edge", 275, "Reward from quest Snakestone of the Shadow Huntress, given in Everlook (Winterspring)" );
	addTradeSkill( "Annihilator", 300, "9% drop from the Quartermaster in LBRS" );
	addTradeSkill( "Arcanite Reaper", 300, "6% drop from rare spawn in LBRS Bannok Grimaxe" );
	addTradeSkill( "Dark Iron Destroyer", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Nightfall", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );

	addTradeSkill( "Fel Sharpening Stone", 300, "Trainer" );
	addTradeSkill( "Fel Weightstone", 300, "Trainer" );
	addTradeSkill( "Fel Iron Rod", 300, "Trainer" );
	addTradeSkill( "Fel Iron Chain Coif", 300, "Trainer" );
	addTradeSkill( "Fel Iron Plate Gloves", 300, "Trainer" );
	addTradeSkill( "Fel Iron Plate Belt", 305, "Trainer" );
	addTradeSkill( "Fel Iron Hatchet", 310, "Trainer" );
	addTradeSkill( "Fel Iron Chain Gloves", 310, "Trainer" );

	addTradeSkill( "Fel Iron Plate Boots", 315, "Trainer" );
	addTradeSkill( "Fel Iron Plate Pants", 315, "Trainer" );
	addTradeSkill( "Fel Iron Chain Bracers", 315, "Trainer" );
	addTradeSkill( "Fel Iron Hammer", 315, "Trainer" );

	addTradeSkill( "Fel Iron Greatsword", 320, "Trainer" );
	addTradeSkill( "Fel Iron Chain Tunic", 320, "Trainer" );

	addTradeSkill( "Adamantite Maul", 325, "Vendor" );
	addTradeSkill( "Fel Iron Breastplate", 325, "Trainer" );
	addTradeSkill( "Lesser Rune of Warding", 325, "Trainer" );

	addTradeSkill( "Adamantite Cleaver", 330, "Vendor" );
	addTradeSkill( "Adamantite Dagger", 330, "Vendor" );
	addTradeSkill( "Heavy Earthforged Breastplate", 330, "Armorsmith", "Trainer" );
	addTradeSkill( "Stormforged Hauberk", 330, "Armorsmith", "Trainer" );
	addTradeSkill( "Windforged Rapier", 330, "Swordsmith", "Trainer" );
	addTradeSkill( "Stoneforged Claymore", 330, "Swordsmith", "Trainer" );
	addTradeSkill( "Stoneforged Claymore", 330, "Hammersmith", "Trainer" );
	addTradeSkill( "Great Earthforged Hammer", 330, "Hammersmith", "Trainer" );
	addTradeSkill( "Lavaforged Hammer", 330, "Hammersmith", "Trainer" );
	addTradeSkill( "Skyforged Great Axe", 330, "Axesmith", "Trainer" );
	addTradeSkill( "Stormforged Axe", 330, "Axesmith", "Trainer" );

	addTradeSkill( "Adamantite Rapier", 335, "Vendor" );
	addTradeSkill( "Adamantite Plate Bracers", 335, "Vendor" );
	addTradeSkill( "Adamantite Plate Gloves", 335, "Vendor" );

	addTradeSkill( "Lesser Rune of Shielding", 340, "Vendor" );
	addTradeSkill( "Adamantite Breastplate", 340, "Vendor" );

	addTradeSkill( "Felsteel Whisper Knives", 350, "Trainer" );
	addTradeSkill( "Adamantite Sharpening Stone", 350, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Greater Rune of Warding", 350, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Adamantite Rod", 350, "Vendor" );
	addTradeSkill( "Adamantite Weightstone", 350, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Flamebane Bracers", 350, "You can purchase this from Quartermaster Endarin in Shattrath City when you are friendly with Aldor" );
	addTradeSkill( "Nether Chain Shirt", 350, "Armorsmith", "Trainer" );
	addTradeSkill( "Breastplate of Kings", 350, "Armorsmith", "Trainer" );
	addTradeSkill( "The Planar Edge", 350, "Axesmith", "Trainer" );
	addTradeSkill( "Drakefist Hammer", 350, "Hammersmith", "Trainer" );
	addTradeSkill( "Fireguard", 350, "Swordsmith", "Trainer" );
	addTradeSkill( "Lionheart Blade", 350, "Swordsmith", "Trainer" );
	addTradeSkill( "Drakefist Hammer", 350, "Swordsmith", "Trainer" );
	addTradeSkill( "Lunar Crescent", 350, "Axesmith", "Trainer" );

	addTradeSkill( "Enchanted Adamantite Belt", 355, "You can buy this from Quartermaster Enuril in Shattrath when you are friendly with Scryers" );
	addTradeSkill( "Enchanted Adamantite Boots", 355, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Flamebane Helm", 355, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );

	addTradeSkill( "Enchanted Adamantite Breastplate", 360, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Flamebane Gloves", 360, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Felsteel Gloves", 360, "BoP mob drop from Auchenai Monks in Auchenai Crypts.  Only blacksmiths can see this drop" );
	addTradeSkill( "Felsteel Leggings", 360, "BoP mob drop from Unchained Doombringer in The Arcatraz.  Only blacksmiths can see this drop" );
	addTradeSkill( "Khorium Belt", 360, "BoP mob drop from Murkblood Raiders in Nagrand" );
	addTradeSkill( "Khorium Pants", 360, "BoP mob drop from Deathforge Guardians in Shadowmoon Valley" );
	addTradeSkill( "Felsteel Shield Spike", 360, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are exalted with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are exalted with Thrallmar" );

	addTradeSkill( "Enchanted Adamantite Leggings", 365, "You can buy this from Quartermaster Enuril in Shattrath when you are exalted with Scryers" );
	addTradeSkill( "Flamebane Breastplate", 365, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Felsteel Helm", 365, "BoP mob drop from Cabal Fanatic in Shadow Labyrinth" );
	addTradeSkill( "Gauntlets of the Iron Tower", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Khorium Boots", 365, "BoP mob drop from Disembodied Protector in Netherstorm" );
	addTradeSkill( "Ragesteel Gloves", 365, "BoP mob drop from Boulderfist Warrior in Nagrand" );
	addTradeSkill( "Felfury Gauntlets", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Steelgrip Gauntlets", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Storm Helm", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Helm of the Stalwart Defender", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Oathkeeper's Helm", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Black Felsteel Bracers", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Bracers of the Green Fortress", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Blessed Bracers", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Felsteel Longblade", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Khorium Champion", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Fel Edged Battleaxe", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Felsteel Reaper", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Runic Hammer", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Fel Hardened Maul", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Eternium Runed Blade", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Dirge", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Hand of Eternity", 365, "World Drop (Buy on AH)" );
	addTradeSkill( "Ragesteel Helm", 365, "BoP mob drop from Anger Guards in Blade's Edge Mountains" );

	addTradeSkill( "Ragesteel Breastplate", 370, "BoP mob drop from Ashtongue Warrior in Shadowmoon Valley" );
	addTradeSkill( "Swiftsteel Gloves", 370, "BoP mob drop from Nexus Stalkers in Mana-Tombs" );
 
	addTradeSkill( "Earthpeace Breastplate", 370, "BoP mob drop from High Botanist Freywinn in The Botanica" );

	addTradeSkill( "Greater Rune of Shielding", 375, "BoP mob drop from Sunfury Bloodwarders in Netherstorm" );
	addTradeSkill( "Eternium Rod", 375, "Vendor" );
	addTradeSkill( "Twisting Nether Chain Shirt", 375, "Armorsmith", "Trainer" );
	addTradeSkill( "Embrace of the Twisting Nether", 375, "Armorsmith", "Trainer" );
	addTradeSkill( "Bulwark of Kings", 375, "Armorsmith", "Trainer" );
	addTradeSkill( "Bulwark of the Ancient Kings", 375, "Armorsmith", "Trainer" );
	addTradeSkill( "Wildguard Breastplate", 375, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are exalted with Cenarion Expedition" );
	addTradeSkill( "Wildguard Leggings", 375, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are revered with Cenarion Expedition" );
	addTradeSkill( "Wildguard Helm", 375, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are revered with Cenarion Expedition" );
	addTradeSkill( "Iceguard Breastplate", 375, "You can purchase this from Koren in Karazhan when you are honored with The Violet Eye" );
	addTradeSkill( "Iceguard Leggings", 375, "You can purchase this from Koren in Karazhan when you are revered with The Violet Eye" );
	addTradeSkill( "Iceguard Helm", 375, "You can purchase this from Koren in Karazhan when you are honored with The Violet Eye" );
	addTradeSkill( "Black Planar Edge", 375, "Axesmith", "Trainer" );
	addTradeSkill( "Blazefury", 375, "Swordsmith", "Trainer" );
	addTradeSkill( "Blazeguard", 375, "Swordsmith", "Trainer" );
	addTradeSkill( "Bloodmoon", 375, "Axesmith", "Trainer" );
	addTradeSkill( "Deep Thunder", 375, "Hammersmith", "Trainer" );
	addTradeSkill( "Dragonmaw", 375, "Hammersmith", "Trainer" );
	addTradeSkill( "Dragonstrike", 375, "Hammersmith", "Trainer" );
	addTradeSkill( "Lionheart Champion", 375, "Swordsmith", "Trainer" );
	addTradeSkill( "Lionheart Executioner", 375, "Swordsmith", "Trainer" );
	addTradeSkill( "Mooncleaver", 375, "Axesmith", "Trainer" );
	addTradeSkill( "Stormherald", 375, "Hammersmith", "Trainer" );
	addTradeSkill( "Wicked Edge of the Planes", 375, "Axesmith", "Trainer" );
	
end

-- Initializes the array adding all Cooking recipes.  As of 2.2 there are

function AckisRecipeList:InitCooking()

	AckisRecipeList.InitializeRecipeArray();

	addTradeSkill( "Charred Wolf Meat", 1, "Trainer" );
	addTradeSkill( "Roasted Boar Meat", 1, "Trainer" );
	addTradeSkill( "Brilliant Smallfish", 1 );
	addTradeSkill( "Slitherskin Mackerel", 1 );
	addTradeSkill( "Herb Baked Egg", 1 );
	addTradeSkill( "Crispy Bat Wing", 1 );
	addTradeSkill( "Gingerbread Cookie", 1 );
	addTradeSkill( "Spice Bread", 1 );
	addTradeSkill( "Lynx Steak", 1 );
	addTradeSkill( "Roasted Moongraze Tenderloin", 1, nil, "Alience - quest reward for The Great Moongraze Hunt in Azuremyst Isle" );
	addTradeSkill( "Kaldorei Spider Kabob", 10 );
	addTradeSkill( "Spiced Wolf Meat", 10, nil, "Trainer" );
	addTradeSkill( "Scorpid Surprise", 20 );
	addTradeSkill( "Beer Basted Boar Ribs", 25 );
	addTradeSkill( "Roasted Kodo Meat", 35 );
	addTradeSkill( "Egg Nog", 35 );
	addTradeSkill( "Smoked Bear Meat", 40, nil, "Alliance - Drac Roughcut, Loch Modan [36, 49]" );
	addTradeSkill( "Fillet of Frenzy", 50 );
	addTradeSkill( "Strider Stew", 50 );
	addTradeSkill( "Boiled Clams", 50, nil, "Trainer" );
	addTradeSkill( "Longjaw Mud Snapper", 50 );
	addTradeSkill( "Loch Frenzy Delight", 50 );
	addTradeSkill( "Rainbow Fin Albacore", 50 );
	addTradeSkill( "Coyote Steak", 50, nil, "Trainer" );
	addTradeSkill( "Goretusk Liver Pie", 50 );
	addTradeSkill( "Bat Bites", 50, nil, "Horde - recipe sold by Master Chef Mouldier in Ghostlands" );
	addTradeSkill( "Blood Sausage", 60 );
	addTradeSkill( "Thistle Tea", 60, nil, nil, "Rogue" );
	addTradeSkill( "Crunchy Spider Surprise", 60 );
	addTradeSkill( "Westfall Stew", 75 );
	addTradeSkill( "Crab Cake", 75, nil, "Trainer" );
	addTradeSkill( "Crocolisk Steak", 80 );
	addTradeSkill( "Smoked Sagefish", 80 );
	addTradeSkill( "Dry Pork Ribs", 80, nil, "Trainer" );
	addTradeSkill( "Savory Deviate Delight", 85, nil, "Zone drop in The Barrens" );
	addTradeSkill( "Cooked Crab Claw", 85 );
	addTradeSkill( "Murloc Fin Soup", 90 );
	addTradeSkill( "Dig Rat Stew", 90 );
	addTradeSkill( "Clam Chowder", 90 );
	addTradeSkill( "Crispy Lizard Tail", 100 );
	addTradeSkill( "Bristle Whisker Catfish", 100 );
	addTradeSkill( "Redridge Goulash", 100 );
	addTradeSkill( "Seasoned Wolf Kabob", 100 );
	addTradeSkill( "Gooey Spider Cake", 110 );
	addTradeSkill( "Big Bear Steak", 110 );
	addTradeSkill( "Lean Venison", 110 );
	addTradeSkill( "Succulent Pork Ribs", 110 );
	addTradeSkill( "Crocolisk Gumbo", 120 );
	addTradeSkill( "Hot Lion Chops", 125 );
	addTradeSkill( "Goblin Deviled Clams", 125, nil, "Trainer" );
	addTradeSkill( "Lean Wolf Steak", 125 );
	addTradeSkill( "Curiously Tasty Omelet", 130 );
	addTradeSkill( "Tasty Lion Steak", 150 );
	addTradeSkill( "Heavy Crocolisk Stew", 150 );
	addTradeSkill( "Soothing Turtle Bisque", 175 );
	addTradeSkill( "Barbecued Buzzard Wing", 175 );
	addTradeSkill( "Giant Clam Scorcho", 175 );
	addTradeSkill( "Rockscale Cod", 175 );
	addTradeSkill( "Roast Raptor", 175 );
	addTradeSkill( "Hot Wolf Ribs", 175 );
	addTradeSkill( "Jungle Stew", 175 );
	addTradeSkill( "Carrion Surprise", 175 );
	addTradeSkill( "Mystery Stew", 175 );
	addTradeSkill( "Mithril Headed Trout", 175 );
	addTradeSkill( "Sagefish Delight", 175 );
	addTradeSkill( "Goldthorn Tea", 175, nil, "Learned from Henry Stern, an NPC in Razorfen Downs" );
	addTradeSkill( "Dragonbreath Chili", 200 );
	addTradeSkill( "Heavy Kodo Stew", 200 );
	addTradeSkill( "Spider Sausage", 200, nil, "Trainer" );
	addTradeSkill( "Spiced Chili Crab", 225 );
	addTradeSkill( "Monster Omelet", 225 );
	addTradeSkill( "Cooked Glossy Mightfish", 225 );
	addTradeSkill( "Spotted Yellowtail", 225 );
	addTradeSkill( "Filet of Redgill", 225 );
	addTradeSkill( "Undermine Clam Chowder", 225 );
	addTradeSkill( "Tender Wolf Steak", 225 );
	addTradeSkill( "Grilled Squid", 240 );
	addTradeSkill( "Hot Smoked Bass", 240 );
	addTradeSkill( "Nightfin Soup", 250 );
	addTradeSkill( "Poached Sunscale Salmon", 250 );
	addTradeSkill( "Lobster Stew", 275 );
	addTradeSkill( "Mightfish Steak", 275 );
	addTradeSkill( "Baked Salmon", 275 );
	addTradeSkill( "Runn Tum Tuber Surprise", 275 );
	addTradeSkill( "Smoked Desert Dumplings", 285 );
	addTradeSkill( "Dirge's Kickin' Chimaerok Chops", 300 );
	addTradeSkill( "Buzzard Bites", 300 );
	addTradeSkill( "Ravager Dog", 300 );
	addTradeSkill( "Blackened Trout", 300 );
	addTradeSkill( "Feltail Delight", 300 );
	addTradeSkill( "Clam Bar", 300 );
	addTradeSkill( "Sporeling Snack", 310 );
	addTradeSkill( "Blackened Sporefish", 310 );
	addTradeSkill( "Blackened Basilisk", 310 );
	addTradeSkill( "Stewed Trout", 310, nil, "Trained from Kylene in the Lower City Inn" );
	addTradeSkill( "Grilled Mudfish", 320 );
	addTradeSkill( "Poached Bluefish", 320 );
	addTradeSkill( "Roasted Clefthoof", 325 );
	addTradeSkill( "Warp Burger", 325 );
	addTradeSkill( "Talbuk Steak", 325 );
	addTradeSkill( "Golden Fish Sticks", 325 );
	addTradeSkill( "Crunchy Serpent", 335 );
	addTradeSkill( "Mok'Nathal Shortribs", 335 );
	addTradeSkill( "Spicy Crawdad", 350 );
	addTradeSkill( "Fisherman's Feast", 350, nil, "Trained from Kylene in the Lower City Inn" );
	addTradeSkill( "Hot Buttered Trout", 350, nil, "Trained from Kylene in the Lower City Inn" );
  
end

-- Initializes the array adding all Enchanting recipes.  As of 2.2 there are

function AckisRecipeList:InitEnchanting()

	AckisRecipeList.InitializeRecipeArray();

	-- Original Game Recipes
	addTradeSkill( "Enchant Bracer - Minor Health", 1, "Trainer" );
	addTradeSkill( "Enchant Bracer - Minor Deflection", 1, "Trainer" );
	addTradeSkill( "Runed Copper Rod", 1, "Trainer" );
	addTradeSkill( "Enchant Chest - Minor Health", 15, "Trainer" );
	addTradeSkill( "Lesser Magic Wand", 15, "Trainer" );
	addTradeSkill( "Enchant Chest - Minor Mana", 20, "VENDOR" );
	addTradeSkill( "Enchant Chest - Minor Absorption", 40, "Trainer" );
	addTradeSkill( "Enchant Cloak - Minor Resistance", 45, "Trainer" );
	addTradeSkill( "Minor Wizard Oil", 45, "VENDOR" );
	addTradeSkill( "Enchant Bracer - Minor Stamina", 50, "Trainer" );
	addTradeSkill( "Enchant Chest - Lesser Health", 60, "Trainer" );
	addTradeSkill( "Enchant Bracer - Minor Spirit", 60, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Cloak - Minor Protection", 70, "Trainer" );
	addTradeSkill( "Greater Magic Wand", 70, "Trainer" );
	addTradeSkill( "Enchant Chest - Lesser Mana", 80, "VENDOR");
	addTradeSkill( "Enchant Bracer - Minor Agility", 80, "Trainer" );
	addTradeSkill( "Enchant Bracer - Minor Strength", 80, "World Drop (Buy on AH)"  );
	addTradeSkill( "Enchant Weapon - Minor Beastslayer", 90, "World Drop (Buy on AH)"  );
	addTradeSkill( "Enchant Weapon - Minor Striking", 90, "Trainer" );
	addTradeSkill( "Enchant 2H Weapon - Minor Impact", 100, "Trainer" );
	addTradeSkill( "Enchant 2H Weapon - Lesser Intellect", 100, "VENDOR" );
	addTradeSkill( "Runed Silver Rod", 100, "Trainer" );
	addTradeSkill( "Enchant Shield - Minor Stamina", 105, "Trainer" );
	addTradeSkill( "Enchant 2H Weapon - Lesser Spirit", 110, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Cloak - Minor Agility", 110, "VENDOR" );
	addTradeSkill( "Enchant Cloak - Lesser Protection", 115, "Trainer" );
	addTradeSkill( "Enchant Shield - Lesser Protection", 115, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Chest - Health", 120, "Trainer" );
	addTradeSkill( "Enchant Bracer - Lesser Spirit", 120, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Cloak - Lesser Fire Resistance", 125, "Trainer" );
	addTradeSkill( "Enchant Boots - Minor Stamina", 125, "Trainer" );
	addTradeSkill( "Enchant Boots - Minor Agility", 125, "VENDOR") ;
	addTradeSkill( "Enchant Bracer - Lesser Stamina", 130, "Trainer" );
	addTradeSkill( "Enchant Shield - Lesser Spirit", 130, "Trainer" );
	addTradeSkill( "Enchant Cloak - Lesser Shadow Resistance", 135, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Weapon - Lesser Striking", 140, "Trainer" );
	addTradeSkill( "Enchant Bracer - Lesser Strength", 140, "VENDOR" );
	addTradeSkill( "Enchant Chest - Lesser Absorption", 140, "Trainer" );
	addTradeSkill( "Enchant 2H Weapon - Lesser Impact", 145, "Trainer" );
	addTradeSkill( "Enchant Chest - Mana", 145, "Trainer" );
	addTradeSkill( "Enchant Gloves - Mining", 145, "Mob Drop :  Dark Iron Dwarves, Tunnelers, Demolitionists and Saboteurs, and Balgaras the Foul (Wetlands)" );
	addTradeSkill( "Enchant Gloves - Herbalism", 145, "Mob Drop :  Crazed Ancients and Withered Ancients (Ashenvale), Blackened Ancients, Charred Ancients and Vengeful Ancients (Stonetalon Mountains)" );
	addTradeSkill( "Enchant Gloves - Fishing", 145, "Mob Drop :  Scargil, Torn Fin Murlocs (Hillsbrad Foothills)" );
	addTradeSkill( "Enchant Chest - Minor Stats", 150, "Trainer" );
	addTradeSkill( "Runed Golden Rod", 150, "Trainer" );
	addTradeSkill( "Lesser Mystic Wand", 155, "Trainer" );
	addTradeSkill( "Minor Mana Oil", 150, "VENDOR" );
	addTradeSkill( "Enchant Bracer - Lesser Intellect", 150, "Trainer" );
	addTradeSkill( "Enchant Shield - Lesser Stamina", 155, "Trainer" );
	addTradeSkill( "Enchant Cloak - Defense", 155, "Trainer" );
	addTradeSkill( "Enchant Boots - Lesser Agility", 160, "Trainer" );
	addTradeSkill( "Enchant Chest - Greater Health", 160, "Trainer" );
	addTradeSkill( "Enchant Bracer - Spirit", 165, "Trainer" );
	addTradeSkill( "Enchant Boots - Lesser Stamina", 170, "Trainer" );
	addTradeSkill( "Enchant Bracer - Lesser Deflection", 170, "VENDOR" );
	addTradeSkill( "Enchant Bracer - Stamina", 170, "Trainer" );
	addTradeSkill( "Enchant Weapon - Lesser Beastslayer", 175, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Weapon - Lesser Elemental Slayer", 175, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Cloak - Fire Resistance", 175, "Trainer" );
	addTradeSkill( "Greater Mystic Wand", 175, "Trainer" );
	addTradeSkill( "Enchant Shield - Spirit", 180, "Trainer" );
	addTradeSkill( "Enchant Bracer - Strength", 180, "Trainer" );
	addTradeSkill( "Enchant Chest - Greater Mana", 185, "Trainer" );
	addTradeSkill( "Enchant Boots - Lesser Spirit", 190, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Weapon - Winter's Might", 190, "You can get this randomly as a reward from a christmas quest.  It's also a drop from Father Winter" );
	addTradeSkill( "Enchant Shield - Lesser Block", 195, "World Drop (Buy on AH)"  );
	addTradeSkill( "Enchant Weapon - Striking", 195, "Trainer" );
	addTradeSkill( "Enchant 2H Weapon - Impact", 200, "Trainer" );
	addTradeSkill( "Enchant Gloves - Skinning", 200, "Mob Drop: Nimar the Slayer and Witherbark Trolls (Arathi Highlands)" );
	addTradeSkill( "Enchant Chest - Lesser Stats", 200, "Trainer" );
	addTradeSkill( "Runed Truesilver Rod", 200, "Trainer" );
	addTradeSkill( "Lesser Wizard Oil", 200, "VENDOR" );
	addTradeSkill( "Enchant Cloak - Greater Defense", 205, "Trainer" );
	addTradeSkill( "Enchant Cloak - Resistance", 205, "Trainer" );
	addTradeSkill( "Enchant Shield - Stamina", 210, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Bracer - Intellect", 210, "Trainer" );
	addTradeSkill( "Enchant Gloves - Agility", 210, "Trainer" );
	addTradeSkill( "Enchant Boots - Stamina", 215, "Trainer" );
	addTradeSkill( "Enchant Gloves - Advanced Mining", 215, "Mob Drop: Venture Co. Strip Miner (Stranglethorn Vale)" );
	addTradeSkill( "Enchant Bracer - Greater Spirit", 220, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Chest - Superior Health", 220, "Trainer" );
	addTradeSkill( "Enchant Gloves - Advanced Herbalism", 225, "Mob Drop: Mire Lord, Molt Thorn, Swampwalker, Swampwalker Elder, and Tangled Horror (Swamp of Sorrows)" );
	addTradeSkill( "Enchant Cloak - Lesser Agility", 225, "Mob Drop: Syndicate Assassin (Alterac Mountains), Wastewander Assassin and Wastewander Scofflaw (Tanaris)" );
	addTradeSkill( "Enchant Gloves - Strength", 225, "Trainer" );
	addTradeSkill( "Enchant Boots - Minor Speed", 225, "Trainer" );
	addTradeSkill( "Enchant Shield - Greater Spirit", 230, "Trainer" );
	addTradeSkill( "Enchant Weapon - Demonslaying", 230, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Chest - Superior Mana", 230, "Trainer" );
	addTradeSkill( "Enchant Bracer - Deflection", 235, "VENDOR" );
	addTradeSkill( "Enchant Shield - Frost Resistance", 235, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Boots - Agility", 235, "Trainer" );
	addTradeSkill( "Enchant 2H Weapon - Greater Impact", 240, "Trainer" );
	addTradeSkill( "Enchant Bracer - Greater Strength", 240, "Trainer" );
	addTradeSkill( "Enchant Chest - Stats", 245, "Trainer" );
	addTradeSkill( "Enchant Weapon - Greater Striking", 245, "Trainer" );
	addTradeSkill( "Enchant Bracer - Greater Stamina", 245, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Gloves - Riding Skill", 250, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Gloves - Minor Haste", 250, "Trainer" );
	addTradeSkill( "Enchanted Leather", 250, "Trainer" );
	addTradeSkill( "Enchanted Thorium", 250, "Trainer" );
	addTradeSkill( "Lesser Mana Oil", 250, "Kania (Silithus)" );
	addTradeSkill( "Enchant Bracer - Greater Intellect", 255, "Trainer -- (Formerly Mob Drop: Vilebranch Shadowcaster (The Hinterlands))" );
	addTradeSkill( "Enchant Boots - Greater Stamina", 255, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Weapon - Fiery Weapon", 265, "Mob Drop: Pyromancer Loregrain (Blackrock Depths)" );
	addTradeSkill( "Smoking Heart of the Mountain", 265, "Mob Drop: Lord Roccor (Blackrock Depths)" );
	addTradeSkill( "Enchant Cloak - Greater Resistance", 265, "Trainer -- (Formerly Mob Drop: Atal'ai Witch Doctor (Sunken Temple))" );
	addTradeSkill( "Enchant Shield - Greater Stamina", 265, "VENDOR" );
	addTradeSkill( "Enchant Bracer - Superior Spirit", 270, "Trainer -- (Formerly World Drop (Buy on AH))" );
	addTradeSkill( "Enchant Gloves - Greater Agility", 270, "Trainer -- (Formerly Mob Drop: Legashi Rogue (Azshara))" );
	addTradeSkill( "Enchant Boots - Spirit", 275, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Chest - Major Health", 275, "VENDOR" );
	addTradeSkill( "Wizard Oil", 275, "Kania (Silithus)" );
	addTradeSkill( "Enchant Shield - Superior Spirit", 280, "Trainer -- (Formerly Mob Drop: Scarlet Warder (Eastern Plaguelands))" );
	addTradeSkill( "Enchant Weapon - Icy Chill", 285, "Mob Drop: Anguished Highborne (Winterspring)" );
	addTradeSkill( "Enchant Cloak - Superior Defense", 285, "VENDOR" );
	addTradeSkill( "Enchant Chest - Major Mana", 290, "Trainer -- (Formerly Mob Drop: Scarlet Enchanter (Eastern Plaguelands))" );
	addTradeSkill( "Runed Arcanite Rod", 290, "VENDOR" );
	addTradeSkill( "Enchant Weapon - Strength", 290, "Friendly: Thorium Brotherhood" );
	addTradeSkill( "Enchant Weapon - Agility", 290, "Honored: Timbermaw Hold" );
	addTradeSkill( "Enchant Bracer - Mana Regeneration", 290, "Honored: Argent Dawn" );
	addTradeSkill( "Enchant 2H Weapon - Agility", 290, "Friendly: Timbermaw Hold" );
	addTradeSkill( "Enchant Gloves - Greater Strength", 295, "Trainer" );
	addTradeSkill( "Enchant Boots - Greater Agility", 295, "Trainer" );
	addTradeSkill( "Enchant Bracer - Superior Strength", 295, "Mob Drop: Deadwind Warlock (Deadwind Pass)" );
	addTradeSkill( "Enchant 2H Weapon - Superior Impact", 295, "Mob Drop: Blackhand Elite (Blackrock Spire)" );
	addTradeSkill( "Enchant Weapon - Unholy Weapon", 295, "Mob Drop: Thuzadin Shadowcaster (Stratholme)" );
	addTradeSkill( "Enchant 2H Weapon - Major Intellect", 300, "Mob Drop: Crimson Sorcerer (Stratholme)" );
	addTradeSkill( "Enchant Weapon - Superior Striking", 300, "Mob Drop: Spirestone Warlord (Blackrock Spire)" );
	addTradeSkill( "Enchant Bracer - Superior Stamina", 300, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Weapon - Crusader", 300, "Mob Drop: Scarlet Spellbinder (Western Plaguelands)" );
	addTradeSkill( "Enchant Chest - Greater Stats", 300, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Weapon - Lifestealing", 300, "Mob Drop: Spectral Researcher (Scholomance)" );
	addTradeSkill( "Enchant 2H Weapon - Major Spirit", 300, "Drops from Scholomance Adept (Scholomance)"  );
	addTradeSkill( "Enchant Weapon - Spell Power", 300, "Drops from Molten Core Bosses - bind on pickup" );
	addTradeSkill( "Enchant Weapon - Healing Power", 300, "Drops from Molten Core Bosses - bind on pickup" );
	addTradeSkill( "Enchant Bracer - Healing Power", 300, "Revered: Argent Dawn" );
	addTradeSkill( "Enchant Weapon - Mighty Spirit", 300, "Honored: Thorium Brotherhood" );
	addTradeSkill( "Enchant Weapon - Mighty Intellect", 300, "Revered: Thorium Brotherhood" );
	addTradeSkill( "Enchant Gloves - Threat", 300, "Mob Drop: Emperor Vek'nilash (Ahn'Qiraj) - bind on pickup", "Raid" );
	addTradeSkill( "Enchant Gloves - Shadow Power", 300, "Drops from AQ20 and AQ40 bosses - bind on pickup", "Raid" );
	addTradeSkill( "Enchant Gloves - Frost Power", 300, "Drops from AQ20 and AQ40 bosses - bind on pickup", "Raid" );
	addTradeSkill( "Enchant Gloves - Fire Power", 300, "Drops from AQ20 and AQ40 bosses - bind on pickup", "Raid" );
	addTradeSkill( "Enchant Gloves - Healing Power", 300, "Drops from AQ20 and AQ40 bosses - bind on pickup", "Raid" );
	addTradeSkill( "Enchant Gloves - Superior Agility", 300, "Drops from AQ20 and AQ40 bosses - bind on pickup", "Raid" );
	addTradeSkill( "Enchant Cloak - Greater Fire Resistance", 300, "Friendly: Cenarion Circle" );
	addTradeSkill( "Enchant Cloak - Greater Nature Resistance", 300, "Honored: Cenarion Circle" );
	addTradeSkill( "Enchant Cloak - Stealth", 300, "Drops from AQ20 and AQ40 bosses - bind on pickup", "Raid" );
	addTradeSkill( "Enchant Cloak - Subtlety", 300, "Mob Drop: Emperor Vek'lor (Ahn'Qiraj) - bind on pickup", "Raid" );
	addTradeSkill( "Enchant Cloak - Dodge", 300, "Drops from AQ20 and AQ40 bosses - bind on pickup", "Raid" );
	addTradeSkill( "Brilliant Wizard Oil", 300, "Honored: Zandalar Tribe" );
	addTradeSkill( "Brilliant Mana Oil", 300, "Friendly: Zandalar Tribe" );

	-- Burning Crusade Recipes
	addTradeSkill( "Runed Fel Iron Rod", 300, "Trainer" );
	addTradeSkill( "Enchant Chest - Restore Mana Prime", 300, "Trainer" );
	addTradeSkill( "Enchant Bracer - Assault", 300, "Trainer" );
	addTradeSkill( "Enchant Boots - Vitality", 305, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Gloves - Blasting", 305, "Trainer" );
	addTradeSkill( "Enchant Bracer - Brawn", 305, "Trainer" );
	addTradeSkill( "Enchant Bracer - Major Intellect", 305, "Trainer" );
	addTradeSkill( "Superior Mana Oil", 310, "Vendor" );
	addTradeSkill( "Enchant Gloves - Assault", 310, "Trainer" );
	addTradeSkill( "Enchant Shield - Tough Shield", 310, "Trainer" );
	addTradeSkill( "Enchant Cloak - Greater Agility", 310, "Trainer" );
	addTradeSkill( "Enchant Cloak - Major Armor", 310, "Trainer" );
	addTradeSkill( "Enchant Bracer - Stats", 315, "Trainer" );
	addTradeSkill( "Enchant Chest - Exceptional Health", 315, "Trainer" );
	addTradeSkill( "Enchant Bracer - Major Defense", 320, "BoP mob drop from Ethereum Researchers in Netherstorm.  STARTING WITH PATCH 2.1 it will drop from Ethereum Nullifiers instead." );
	addTradeSkill( "Enchant Boots - Fortitude", 320, "BoP mob drop from Ethereal Priests in Mana-Tombs" );
	addTradeSkill( "Enchant Chest - Major Spirit", 320, "Trainer" );
	addTradeSkill( "Prismatic Sphere", 325, "Trainer" );
	addTradeSkill( "Enchant Bracer - Superior Healing", 325, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are friendly with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are friendly with Thrallmar" );
	addTradeSkill( "Enchant Shield - Intellect", 325, "Vendor" );
	addTradeSkill( "Enchant Cloak - Spell Penetration", 325, "Friendly: The Consortium" );
	addTradeSkill( "Enchant Shield - Major Stamina", 325, "Vendor" );
	addTradeSkill( "Enchant Cloak - Major Resistance", 330, "World Drop (Buy on AH)" );
	addTradeSkill( "Large Prismatic Shard", 325, "VENDOR" );
	addTradeSkill( "Enchant Bracer - Restore Mana Prime", 335, "World Drop (Buy on AH)" );
	addTradeSkill( "Superior Wizard Oil", 340, "VENDOR" );
	addTradeSkill( "Enchant Shield - Shield Block", 340, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Boots - Dexterity", 340, "BoP mob drop from Raging Skeletons in Auchenai Crypts" );
	addTradeSkill( "Enchant Weapon - Major Intellect", 340, "BoP mob drop from Sunfury Researchers in Netherstorm" );
	addTradeSkill( "Enchant Gloves - Major Strength", 340, "Trainer" );
	addTradeSkill( "Enchant Weapon - Major Striking", 340, "Honored: The Consortium" );
	addTradeSkill( "Enchant Chest - Exceptional Stats", 345, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are revered with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are revered with Thrallmar" );
	addTradeSkill( "Enchant Chest - Major Resilience", 345, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Bracer - Fortitude", 350, "BoP mob drop from Coilfang Oracles in The Steamvault" );
	addTradeSkill( "Enchant 2H Weapon - Savagery", 350, "BoP mob drop from Shattered Hand Centurions in The Shattered Halls" );
	addTradeSkill( "Enchant Weapon - Potency", 350, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Weapon - Major Spellpower", 350, "BoP mob drop from Razaani Spell-Thiefs (Thieves?) in Blade's Edge Mountains" );
	addTradeSkill( "Void Sphere", 350, "Trainer" );
	addTradeSkill( "Runed Adamantite Rod", 350, "Vendor" );
	addTradeSkill( "Enchant Gloves - Major Healing", 350, "Honored: The Sha'tar" );
	addTradeSkill( "Enchant Cloak - Greater Arcane Resistance", 350, "BoP mob drop from Eclipsion Archmages in Shadowmoon Valley" );
	addTradeSkill( "Enchant Cloak - Greater Shadow Resistance", 350, "BoP mob drop from Voidshriekers in Netherstorm" );
	addTradeSkill( "Enchant Weapon - Major Healing", 350, "You can buy this from Almaador in Shattrath when you are revered with The Sha'tar" );
	addTradeSkill( "Enchant Bracer - Spellpower", 360, "BoP mob drop from Bloodmaul Geomancers in Blade's Edge Mountains" );
	addTradeSkill( "Enchant Ring - Striking", 360, "Revered: The Consortium", "Raid" );
	addTradeSkill( "Enchant Ring - Spellpower", 360, "Honored: Keepers of Time" );
	addTradeSkill( "Enchant Shield - Resistance", 360, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant 2H Weapon - Major Agility", 360, "BoP mob drop from Eredar Deathbringer in The Arcatraz" );
	addTradeSkill( "Enchant Weapon - Spellsurge", 360, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Weapon - Battlemaster", 360, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Gloves - Spell Strike", 360, "Revered: Cenarion Expedition" );
	addTradeSkill( "Enchant Gloves - Major Spellpower", 360, "Honored: Keepers of Time" );
	addTradeSkill( "Enchant Boots - Cat's Swiftness", 360, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Boots - Boar's Speed", 360, "World Drop (Buy on AH)" );
	addTradeSkill( "Enchant Ring - Healing Power", 370, "Revered: The Sha'tar" );
	addTradeSkill( "Enchant Boots - Surefooted", 370, "Karazhan: Enchanted Stagehands", "Raid" );
	addTradeSkill( "Runed Eternium Rod", 375, "Vendor" );
	addTradeSkill( "Enchant Ring - Stats", 375, "Revered: Scale of the Sands", "Raid" );
	addTradeSkill( "Enchant Weapon - Sunfire", 375, "Karazhan: Shade of Aran", "Raid" );
	addTradeSkill( "Enchant Weapon - Soulfrost", 375, "Karazhan: Illhoof", "Raid" );
	addTradeSkill( "Enchant Weapon - Mongoose", 375, "Karazhan: Moroes", "Raid" );

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all Engineering recipes.  As of 2.2 there are

function AckisRecipeList:InitEngineering()

	AckisRecipeList.InitializeRecipeArray();

	addTradeSkill( "Rough Blasting Powder", 1, "Trainer" );
	addTradeSkill( "Rough Dynamite", 1, "Trainer" );
	addTradeSkill( "Crafted Light Shot", 1, nil, "Trainer" );
	addTradeSkill( "Handful of Copper Bolts", 30, nil, "Trainer" );
	addTradeSkill( "Rough Copper Bomb", 30, nil, "Trainer" );
	addTradeSkill( "Copper Tube", 50, nil, "Trainer" );
	addTradeSkill( "Rough Boomstick", 50, nil, "Trainer" );
	addTradeSkill( "Arclight Spanner", 50, nil, "Trainer" );
	addTradeSkill( "Crude Scope", 60, nil, "Trainer" );
	addTradeSkill( "Copper Modulator", 65, nil, "Trainer" );
	addTradeSkill( "Mechanical Squirrel", 75, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Coarse Blasting Powder", 75, nil, "Trainer" );
	addTradeSkill( "Crafted Heavy Shot", 75, nil, "Trainer" );
	addTradeSkill( "Coarse Dynamite", 75, nil, "Trainer" );
	addTradeSkill( "Target Dummy", 85, nil, "Trainer" );
	addTradeSkill( "Silver Contact", 90, nil, "Trainer" );
	addTradeSkill( "Small Seaforium Charge", 100, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Flying Tiger Goggles", 100, nil, "Trainer" );
	addTradeSkill( "Practice Lock", 100, nil, "Trainer" );
	addTradeSkill( "EZ-Thro Dynamite", 100, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Deadly Blunderbuss", 105, nil, "Trainer" );
	addTradeSkill( "Large Copper Bomb", 105, nil, "Trainer" );
	addTradeSkill( "Bronze Tube", 105, nil, "Trainer" );
	addTradeSkill( "Standard Scope", 110, nil, "Trainer" );
	addTradeSkill( "Lovingly Crafted Boomstick", 120, nil, "VENDOR" );
	addTradeSkill( "Shadow Goggles", 120, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Small Bronze Bomb", 120, nil, "Trainer" );
	addTradeSkill( "Whirring Bronze Gizmo", 125, nil, "Trainer" );
	addTradeSkill( "Flame Deflector", 125, nil, "Mob Drop : Mekgineer Thermaplug (Gnomeregan)" );
	addTradeSkill( "Heavy Blasting Powder", 125, nil, "Trainer" );
	addTradeSkill( "Heavy Dynamite", 125, nil, "Trainer" );
	addTradeSkill( "Crafted Solid Shot", 125, nil, "Trainer" );
	addTradeSkill( "Gnomish Universal Remote", 125, nil, "VENDOR" );
	addTradeSkill( "Small Blue Rocket", 125, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Small Green Rocket", 125, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Small Red Rocket", 125, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Silver-plated Shotgun", 130, nil, "Trainer" );
	addTradeSkill( "Ornate Spyglass", 135, nil, "Trainer" );
	addTradeSkill( "Big Bronze Bomb", 140, nil, "Trainer" );
	addTradeSkill( "Minor Recombobulator", 140, nil, "VENDOR" );
	addTradeSkill( "Bronze Framework", 140, nil, "Trainer" );
	addTradeSkill( "Moonsight Rifle", 145, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Explosive Sheep", 150, nil, "Trainer" );
	addTradeSkill( "Green Tinted Goggles", 150, nil, "Trainer" );
	addTradeSkill( "Aquadynamic Fish Attractor", 150, nil, "Trainer" );
	addTradeSkill( "Gold Power Core", 150, nil, "Trainer" );
	addTradeSkill( "Red Firework", 150, nil, "VENDOR" );
	addTradeSkill( "Green Firework", 150, nil, "VENDOR" );
	addTradeSkill( "Blue Firework", 150, nil, "VENDOR" );
	addTradeSkill( "Ice Deflector", 155, nil, "VENDOR" );
	addTradeSkill( "Iron Strut", 160, nil, "Trainer" );
	addTradeSkill( "Discombobulator Ray", 160, nil, "Mob Drop: Mekgineer Thermaplugg (Gnomeregan)" );
	addTradeSkill( "Portable Bronze Mortar", 165, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Goblin Jumper Cables", 165, nil, "VENDOR" );
	addTradeSkill( "Gyrochronatom", 170, nil, "Trainer" );
	addTradeSkill( "Iron Grenade", 175, nil, "Trainer" );
	addTradeSkill( "Compact Harvest Reaper Kit", 175, nil, "Trainer" );
	addTradeSkill( "Solid Blasting Powder", 175, nil, "Trainer" );
	addTradeSkill( "Solid Dynamite", 175, nil, "Trainer" );
	addTradeSkill( "Bright-Eye Goggles", 175, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Gyromatic Micro-Adjustor", 175, nil, "Trainer" );
	addTradeSkill( "Large Blue Rocket", 175, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Large Green Rocket", 175, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Large Red Rocket", 175, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Accurate Scope", 180, nil, "VENDOR" );
	addTradeSkill( "Advanced Target Dummy", 185, nil, "Trainer" );
	addTradeSkill( "Craftsman's Monocle", 185, nil, "World Drop (Buy on AH)"  );
	addTradeSkill( "Flash Bomb", 185, nil, "Reward from quest (Flash Bomb Recipe) obtained from Rigglefuzz in Badlands.  Must first complete Pearl Diving quest." );
	addTradeSkill( "Big Iron Bomb", 190, nil, "Trainer" );
	addTradeSkill( "SnowMaster 9000", 190, nil, "You can get this randomly as a reward from a Feast of Winter Veil quest.  It's also a drop from Father Winter"  );
	addTradeSkill( "Goblin Land Mine", 195, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Mithril Tube", 195, nil, "Trainer" );
	addTradeSkill( "Mechanical Dragonling", 200, nil, "VENDOR" );
	addTradeSkill( "Gnomish Cloaking Device", 200, nil, "VENDOR" );
	addTradeSkill( "Large Seaforium Charge", 200, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Unstable Trigger", 200, nil, "Trainer" );
	addTradeSkill( "Mechanical Repair Kit", 200, nil, "Trainer" );
	addTradeSkill( "EZ-Thro Dynamite II", 200, nil, "VENDOR" );
	addTradeSkill( "Fire Goggles", 205, nil, "Trainer" );
	addTradeSkill( "Mithril Blunderbuss", 205, nil, "Trainer" );
	addTradeSkill( "Hi-Impact Mithril Slugs", 210, nil, "Trainer" );
	addTradeSkill( "Deadly Scope", 210, nil, "VENDOR" );
	addTradeSkill( "Mithril Casing", 215, nil, "Trainer" );
	addTradeSkill( "Mithril Frag Bomb", 215, nil, "Trainer" );
	addTradeSkill( "Catseye Ultra Goggles", 220, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Mithril Heavy-bore Rifle", 220, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Goblin Rocket Boots", 225, nil, "Trainer" );
	addTradeSkill( "Spellpower Goggles Xtreme", 225, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Parachute Cloak", 225, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Blue Rocket Cluster", 225, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Green Rocket Cluster", 225, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Red Rocket Cluster", 225, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Firework Launcher", 225, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Deepdive Helmet", 230, nil, "VENDOR" );
	addTradeSkill( "Rose Colored Goggles", 230, nil, "Trainer" );
	addTradeSkill( "Hi-Explosive Bomb", 235, nil, "Trainer" );
	addTradeSkill( "Sniper Scope", 240, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Mithril Gyro-Shot", 245, nil, "Trainer" );
	addTradeSkill( "Green Lens", 245, nil, "Trainer" );
	addTradeSkill( "Mithril Mechanical Dragonling", 250, nil, "VENDOR" );
	addTradeSkill( "Salt Shaker", 250, nil, "Trainer" );
	addTradeSkill( "Dense Blasting Powder", 250, nil, "Trainer" );
	addTradeSkill( "Dense Dynamite", 250, nil, "Trainer" );
	addTradeSkill( "Snake Burst Firework", 250, nil, "VENDOR" );
	addTradeSkill( "Tranquil Mechanical Yeti", 250, "Trainer: Can learn recipe after completing quest (Are We There Yeti) obtained from Umi Rumplesnicker in Winterspring" );
	addTradeSkill( "Thorium Grenade", 260, nil, "VENDOR" );
	addTradeSkill( "Thorium Rifle", 260, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Thorium Widget", 260, nil, "VENDOR" );
	addTradeSkill( "Truesilver Transformer", 260, nil, "VENDOR" );
	addTradeSkill( "Gyrofreeze Ice Reflector", 260, nil, "VENDOR" );
	addTradeSkill( "Lifelike Mechanical Toad", 265, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Spellpower Goggles Xtreme Plus", 270, nil, "Mob Drop: Spitelash Siren (Azshara)" );
	addTradeSkill( "Dark Iron Rifle", 275, nil, "Mob Drop: Doomforge Craftsman (Blackrock Depths)" );
	addTradeSkill( "Masterwork Target Dummy", 275, nil, "VENDOR" );
	addTradeSkill( "Thorium Tube", 275, nil, "VENDOR" );
	addTradeSkill( "Major Recombobulator", 275, nil, "Gordok Tribute (Dire Maul) and Mob Drop: King Gordok (Dire Maul)" );
	addTradeSkill( "Powerful Seaforium Charge", 275, nil, "VENDOR" );
	addTradeSkill( "Large Blue Rocket Cluster", 275, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Large Green Rocket Cluster", 275, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Large Red Rocket Cluster", 275, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Firework Cluster Launcher", 275, nil, "Reward from Lunar Festival quest" );
	addTradeSkill( "Steam Tonk Controller", 275, nil, nil );
	addTradeSkill( "Delicate Arcanite Converter", 285, nil, "VENDOR" );
	addTradeSkill( "Dark Iron Bomb", 285, nil, "Mob Drop: Weapon Technician (Blackrock Depths and Blackrock Mountain)" );
	addTradeSkill( "Thorium Shells", 285, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Voice Amplification Modulator", 290, nil, "Mob Drop: Crimson Inquisitor (Stratholme)" );
	addTradeSkill( "Master Engineer's Goggles", 290, nil, "Mob Drop: Doomforge Arcanasmith (Blackrock Depths and Blackrock Mountain)" );
	addTradeSkill( "Hyper-Radiant Flame Reflector", 290, nil, "Mob Drop: Solakar Flamewreath (Hall of Blackhand)" );
	addTradeSkill( "Arcane Bomb", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Arcanite Dragonling", 300, nil, "Mob Drop: Cobalt MAgeweaver (Winterspring)" );
	addTradeSkill( "Flawless Arcanite Rifle", 300, nil, "Mob Drop: Mossflayer Shadowhunter (Eastern Plaguelands)" );
	addTradeSkill( "Field Repair Bot 74A", 300, nil, "Recipe can be looted by Golem Lord Argelmach in Blackrock Depths.  Must have 300 skill to pick it up." );
	addTradeSkill( "Biznicks 247x128 Accurascope", 300, nil, "Mob Drop: Molten Core bosses - binds when picked up" );
	addTradeSkill( "Core Marksman Rifle", 300, nil, "Mob Drop: Molten Core bosses - binds when picked up" );
	addTradeSkill( "Force Reactive Disk", 300, nil, "Mob Drop: Molten Core bosses - binds when picked up" );
	addTradeSkill( "Ultra-Flash Shadow Reflector", 300, nil, "Mob Drop: Crimson Inquisitor (Stratholme)" );
	addTradeSkill( "Bloodvine Goggles", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with the Zandalar Tribe"  );
	addTradeSkill( "Bloodvine Lens", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are friendly with the Zandalar Tribe" );

	addTradeSkill( "Inlaid Mithril Cylinder Plans", 200, "Gnomish" );
	addTradeSkill( "Lil' Smoky", 205, "Gnomish", "Possible reward from renewing membership with Gnomish trainer" );
	addTradeSkill( "Gnomish Shrink Ray", 205, "Gnomish", "Trainer", "Trainer" );
	addTradeSkill( "Gnomish Goggles", 210, "Gnomish", "Trainer" );
	addTradeSkill( "Gnomish Net-o-Matic Projector", 210, "Gnomish", "Trainer" );
	addTradeSkill( "Gnomish Harm Prevention Belt", 215, "Gnomish", "Trainer" );
	addTradeSkill( "Gnomish Rocket Boots", 225, "Gnomish", "Trainer" );
	addTradeSkill( "Gnomish Battle Chicken", 230, "Gnomish", "Trainer" );
	addTradeSkill( "Gnomish Mind Control Cap", 235, "Gnomish", "Trainer" );
	addTradeSkill( "Gnomish Death Ray", 240, "Gnomish", "Trainer" );
	addTradeSkill( "World Enlarger", 260, "Gnomish", "Mob Drop: Weapon Technician (Blackrock Depths and Blackrock Mountain)" );
	addTradeSkill( "Ultrasafe Transporter - Gadgetzan", 260, "Gnomish", "Talk to the guy in Gadgetzan by the transporter" );
	addTradeSkill( "Alarm-O-Bot", 265, "Gnomish", "Mob Drop: Weapon Technician (Blackrock Depths and Blackrock Mountain)" );

	addTradeSkill( "Goblin Construction Helmet", 205, "Goblin","Trainer" );
	addTradeSkill( "Goblin Mining Helmet", 205, "Goblin", "Trainer" );
	addTradeSkill( "Pet Bombling", 205, "Goblin", "Possible reward from renewing membership with Goblin trainer" );
	addTradeSkill( "Goblin Mortar", 205, "Goblin",  "Trainer" );
	addTradeSkill( "The Mortar: Reloaded", 205, "Goblin", "Trainer" );
	addTradeSkill( "Goblin Sapper Charge", 205, "Goblin", "Trainer" );
	addTradeSkill( "Goblin Rocket Boots", 225, "Goblin", "Trainer" );
	addTradeSkill( "Goblin Bomb Dispenser", 230, "Goblin", "Trainer" );
	addTradeSkill( "The Big One", 235, "Goblin", "Trainer" );
	addTradeSkill( "Goblin Rocket Helmet", 245, "Goblin", "Trainer" );
	addTradeSkill( "Dimensional Ripper - Everlook", 260, "Goblin", "Talk to the guy in Everlook by the transporter" );
	addTradeSkill( "Goblin Jumper Cables XL", 265, "Goblin", "Mob Drop: Plugger Spazzring (Blackrock Depths)" );
	addTradeSkill( "Goblin Rocket Fuel Recipe", 205, "Goblin", "Trainer" );
	addTradeSkill( "Goblin Dragon Gun", 240, "Goblin", "Trainer" );

	addTradeSkill( "Fel Iron Bomb", 300, nil, "Trainer" );
	addTradeSkill( "Fel Iron Casing", 300, nil, "Trainer" );
	addTradeSkill( "Elemental Blasting Powder", 300, nil, "Trainer" );
	addTradeSkill( "Handful of Fel Iron Bolts", 300, nil, "Trainer" );

	addTradeSkill( "Zapthrottle Mote Extractor", 305, nil, "recipe is a BoP quest reward from Zapthrottle Mote Extractor!, given to Alliance by K. Lee Smallfry, to Horde by Mack Diver, both in Zangarmarsh" );

	addTradeSkill( "Fel Iron Shells", 310, nil, "Trainer" );

	addTradeSkill( "Fel Iron Musket", 320, nil, "Trainer" );

	addTradeSkill( "Fel Iron Toolbox", 325, nil, "Vendor" );
	addTradeSkill( "Gnomish Flame Turret", 325, "Gnomish", "Trainer" );
	addTradeSkill( "Crashin' Thrashin' Robot", 325, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Adamantite Frame", 325, nil, "Trainer" );
	addTradeSkill( "The Bigger One", 325, "Goblin", "Trainer" );
	addTradeSkill( "Adamantite Grenade", 325, nil, "Trainer" );

	addTradeSkill( "Healing Potion Injector", 330, nil, "World Drop (Buy on AH)" );

	addTradeSkill( "Adamantite Scope", 335, nil, "VENDOR" );
	addTradeSkill( "White Smoke Flare", 335, nil, "VENDOR" );
	addTradeSkill( "Green Smoke Flare", 335, nil, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are friendly with Cenarion Expedition" );
	addTradeSkill( "Adamantite Shells", 335, nil, "VENDOR" );
	addTradeSkill( "Purple Smoke Flare", 335, nil, "World Drop (Buy on AH)" );

	addTradeSkill( "Super Sapper Charge", 340, "Goblin", "Trainer" );
	addTradeSkill( "Cogspinner Goggles", 340, nil, "VENDOR" );
	addTradeSkill( "Power Amplification Goggles", 340, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Gnomish Poultryizer", 340, "Gnomish", "Trainer" );

	addTradeSkill( "Mana Potion Injector", 345, nil, "World Drop (Buy on AH)" );

	addTradeSkill( "Adamantite Rifle", 350, nil, "Vendor" );
	addTradeSkill( "Goblin Rocket Launcher", 350, "Goblin", "Trainer" );
	addTradeSkill( "Ultra-Spectropic Detection Goggles", 350, nil, "VENDOR" );
	addTradeSkill( "Khorium Power Core", 350, nil, "Trainer" );
	addTradeSkill( "Felsteel Stabilizer", 350, nil, "Trainer" );
	addTradeSkill( "Hardened Adamantite Tube", 350, nil, "Trainer" );
	addTradeSkill( "Dimensional Ripper - Area 52", 350, "Goblin", "Talk to the guy in Area 52 by the transporter" );
	addTradeSkill( "Ultrasafe Transporter - Toshley's Station", 260, "Gnomish", "Talk to the guy outside Toshley's Station by the transporter" );

	addTradeSkill( "Rocket Boots Xtreme", 355, nil, "BoP mob drop from Mekgineer Steamrigger in The Steamvault" );
	addTradeSkill( "Felsteel Boomstick", 360, nil, "BoP mob drop from Doomforge Engineer in Blade's Edge Mountains" );
	addTradeSkill( "Hyper-Vision Goggles", 360, nil, "BoP mob drop from Mo'arg Weaponsmiths in Shadowmoon Valley" );
	addTradeSkill( "Khorium Scope", 360, nil, "BoP mob drop from Sunfury Bowman in Netherstorm" );
	addTradeSkill( "Foreman's Enchanted Helmet", 375, "Goblin", "Trainer" );
	addTradeSkill( "Foreman's Reinforced Helmet", 375, "Goblin", "Trainer" );
	addTradeSkill( "Gnomish Battle Goggles", 375, "Gnomish", "Trainer" );
	addTradeSkill( "Ornate Khorium Rifle", 375, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Stabilized Eternium Scope", 375, nil, "BoP mob drop from Attumen the Huntsman in Karazhan" );
	
end

-- Initializes the array adding all First Aid recipes.  As of 2.2 there are 15 recipes

function AckisRecipeList:InitFirstAid()
  
	AckisRecipeList.InitializeRecipeArray();
  
	-- Original Game Recipes
	addTradeSkill( "Linen Bandage", 1, "Trainer");
	addTradeSkill( "Heavy Linen Bandage", 40, "Trainer");
	addTradeSkill( "Wool Bandage", 80, "Trainer");
	addTradeSkill( "Anti-Venom", 80, "Trainer");
	addTradeSkill( "Heavy Wool Bandage", 115, "Trainer");
	addTradeSkill( "Strong Anti-Venom", 130, "Uncommon World Drop");
	addTradeSkill( "Silk Bandage", 150, "Trainer");
	addTradeSkill( "Heavy Silk Bandage", 180, "Vendor");
	addTradeSkill( "Mageweave Bandage", 210, "Vendor");
	addTradeSkill( "Heavy Mageweave Bandage", 240, "Trainer");
	addTradeSkill( "Runecloth Bandage", 260, "Trainer");
	addTradeSkill( "Heavy Runecloth Bandage", 290, "Trainer");
	addTradeSkill( "Powerful Anti-Venom", 300, "Honored: Argent Dawn");

	-- Burning Crusade Recipes
	addTradeSkill( "Netherweave Bandage", 330, "Vendor");
	addTradeSkill( "Heavy Netherweave Bandage", 360, "Vendor");

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all Jewelcrafting recipes.  As of 2.2 there are

function AckisRecipeList:InitJewelcrafting()

	AckisRecipeList.InitializeRecipeArray();

	addTradeSkill( "Delicate Copper Wire", 1, nil, "Trainer" );
	addTradeSkill( "Braided Copper Ring", 1, nil, "Trainer" );
	addTradeSkill( "Woven Copper Ring", 1, nil, "Trainer" );
	addTradeSkill( "Rough Stone Statue", 1, nil, "Trainer" );
	addTradeSkill( "Heavy Copper Ring", 5, nil, "Trainer" );
	addTradeSkill( "Malachite Pendant", 20, nil, "Trainer" );
	addTradeSkill( "Tigerseye Band", 20, nil, "Trainer" );
	addTradeSkill( "Inlaid Malachite Ring", 30, nil, "Trainer" );
	addTradeSkill( "Ornate Tigerseye Necklace", 30, nil, "Trainer" );
	addTradeSkill( "Bronze Setting", 50, nil, "Trainer" );
	addTradeSkill( "Elegant Silver Ring", 50, nil, "Trainer" );
	addTradeSkill( "Solid Bronze Ring", 50, nil, "Trainer" );
	addTradeSkill( "Thick Bronze Necklace", 50, nil, "Trainer" );
	addTradeSkill( "Coarse Stone Statue", 50, nil, "Trainer" );
	addTradeSkill( "Simple Pearl Ring", 60, nil, "Trainer" );
	addTradeSkill( "Bronze Band of Force", 65, nil, "Trainer" );
	addTradeSkill( "Gloom Band", 70, nil, "Trainer" );
	addTradeSkill( "Brilliant Necklace", 75, nil, "Trainer" );
	addTradeSkill( "Bronze Torc", 80, nil, "Trainer" );
	addTradeSkill( "Heavy Silver Ring", 90, nil, "Trainer" );
	addTradeSkill( "Ring of Silver Might", 100, nil, "Trainer" );
	addTradeSkill( "Ring of Twilight Shadows", 100, nil, "Trainer" );
	addTradeSkill( "Heavy Jade Ring", 105, nil, "Trainer" );
	addTradeSkill( "Amulet of the Moon", 110, nil, "Vendor" );
	addTradeSkill( "Barbaric Iron Collar", 110, nil, "Trainer" );
	addTradeSkill( "Heavy Stone Statue", 110, nil, "Trainer" );
	addTradeSkill( "Moonsoul Crown", 120, nil, "Trainer" );
	addTradeSkill( "Pendant of the Agate Shield", 120, nil, "Vendor" );
	addTradeSkill( "Wicked Moonstone Ring", 125, nil, "Vendor" );
	addTradeSkill( "Heavy Iron Knuckles", 125, nil, "Vendor" );
	addTradeSkill( "Golden Dragon Ring", 135, nil, "Trainer" );
	addTradeSkill( "Heavy Golden Necklace of Battle", 150, nil, "Vendor" );
	addTradeSkill( "Mithril Filigree", 150, nil, "Trainer" );
	addTradeSkill( "Blazing Citrine Ring", 150, nil, "Vendor" );
	addTradeSkill( "Jade Pendant of Blasting", 160, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "The Jade Eye", 170, nil, "Vendor" );
	addTradeSkill( "Engraved Truesilver Ring", 170, nil, "Trainer" );
	addTradeSkill( "Solid Stone Statue", 175, nil, "Trainer" );
	addTradeSkill( "Citrine Ring of Rapid Healing", 180, nil, "Trainer" );
	addTradeSkill( "Golden Ring of Power", 180, nil, "Trainer" );
	addTradeSkill( "Citrine Pendant of Golden Healing", 190, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Figurine - Jade Owl", 200, nil, "Trainer" );
	addTradeSkill( "Figurine - Golden Hare", 200, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Truesilver Commander's Ring", 200, nil, "Trainer" );
	addTradeSkill( "Aquamarine Signet", 210, nil, "Trainer" );
	addTradeSkill( "Figurine - Black Pearl Panther", 215, nil, "Vendor" );
	addTradeSkill( "Aquamarine Pendant of the Warrior", 220, nil, "Trainer" );
	addTradeSkill( "Ruby Crown of Restoration", 225, nil, "Vendor" );
	addTradeSkill( "Thorium Setting", 225, nil, "Trainer" );
	addTradeSkill( "Figurine - Truesilver Crab", 225, nil, "Vendor" );
	addTradeSkill( "Dense Stone Statue", 225, nil, "Trainer" );
	addTradeSkill( "Figurine - Truesilver Boar", 230, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Red Ring of Destruction", 230, nil, "Trainer" );
	addTradeSkill( "Ruby Pendant of Fire", 235, nil, "Trainer" );
	addTradeSkill( "Truesilver Healing Ring", 240, nil, "Trainer" );
	addTradeSkill( "The Aquamarine Ward", 245, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Gem Studded Band", 250, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Opal Necklace of Impact", 250, nil, "VENDOR" );
	addTradeSkill( "Figurine - Ruby Serpent", 260, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Simple Opal Ring", 260, nil, "Trainer" );
	addTradeSkill( "Diamond Focus Ring", 275, nil, "Trainer" );
	addTradeSkill( "Sapphire Signet", 275, nil, "Trainer" );
	addTradeSkill( "Emerald Crown of Destruction", 275, nil, "VENDOR" );
	addTradeSkill( "Onslaught Ring", 280, nil, "Trainer" );
	addTradeSkill( "Sapphire Pendant of Winter Night", 280, nil, "Trainer" );
	addTradeSkill( "Glowing Thorium Band", 280, nil, "Trainer" );
	addTradeSkill( "Figurine - Emerald Owl", 285, nil, "World Drop" );
	addTradeSkill( "Ring of Bitter Shadows", 285, nil, "Vendor" );
	addTradeSkill( "Living Emerald Pendant", 290, nil, "Trainer" );
	addTradeSkill( "Emerald Lion Ring", 290, nil, "Trainer" );
	addTradeSkill( "Figurine - Black Diamond Crab", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Figurine - Dark Iron Scorpid", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Teardrop Blood Garnet", 300, nil, "Vendor" );
	addTradeSkill( "Inscribed Flame Spessarite", 300, nil, "Vendor" );
	addTradeSkill( "Radiant Deep Peridot", 300, nil, "Vendor" );
	addTradeSkill( "Glowing Shadow Draenite", 300, nil, "Vendor" );
	addTradeSkill( "Brilliant Golden Draenite", 300, nil, "Vendor" );
	addTradeSkill( "Solid Azure Moonstone", 300, nil, "Vendor" );
	addTradeSkill( "Necklace of the Diamond Tower", 305, nil, "Vendor" );
	addTradeSkill( "Bold Blood Garnet", 305, nil, "Vendor" );
	addTradeSkill( "Luminous Flame Spessarite", 305, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are friendly with The Consortium" );
	addTradeSkill( "Jagged Deep Peridot", 305, nil, "Vendor" );
	addTradeSkill( "Royal Shadow Draenite", 305, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Gleaming Golden Draenite", 305, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are friendly with Aldor" );
	addTradeSkill( "Sparkling Azure Moonstone", 305, nil, "Vendor" );
	addTradeSkill( "Bright Blood Garnet", 305, nil, "Vendor" );
	addTradeSkill( "Band of Natural Fire", 310, nil, "Trainer" );
	addTradeSkill( "Fel Iron Blood Ring", 310, nil, "Trainer" );
	addTradeSkill( "Golden Draenite Ring", 310, nil, "Trainer" );
	addTradeSkill( "Runed Blood Garnet", 315, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are friendly with Scryers" );
	addTradeSkill( "Glinting Flame Spessarite", 315, nil, "Vendor" );
	addTradeSkill( "Enduring Deep Peridot", 315, nil, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are friendly with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are friendly with Thrallmar" );
	addTradeSkill( "Thick Golden Draenite", 315, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Stormy Azure Moonstone", 315, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Azure Moonstone Ring", 320, nil, "Trainer" );
	addTradeSkill( "Delicate Blood Garnet", 325, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Potent Flame Spessarite", 325, nil, "You can buy this from Nakodu in Shattrath City when you are honored with Lower City" );
	addTradeSkill( "Dazzling Deep Peridot", 325, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Shifting Shadow Draenite", 325, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are friendly with The Consortium" );
  --addTrade( "Sovereign Shadow Draenite", 325, nil, "Vendor" ); the correct spelling
	addTradeSkill( "Soveriegn Shadow Draenite", 325, nil, "Vendor" ); -- the bliz spelling
	addTradeSkill( "Rigid Golden Draenite", 325, nil, "Vendor" );
	addTradeSkill( "Lustrous Azure Moonstone", 325, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Smooth Golden Draenite", 325, nil, "VENDOR" );
	addTradeSkill( "Mercurial Adamantite", 325, nil, "Trainer" );
	addTradeSkill( "Heavy Adamantite Ring", 335, nil, "Trainer" );
	addTradeSkill( "Thick Adamantite Necklace", 335, nil, "Trainer" );
	addTradeSkill( "Heavy Felsteel Ring", 345, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Bright Living Ruby", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Brilliant Dawnstone", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Dazzling Talasite", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Delicate Living Ruby", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Enduring Talasite", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Inscribed Noble Topaz", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Flashing Living Ruby", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Gleaming Dawnstone", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Glinting Noble Topaz", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Glowing Nightseye", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Jagged Talasite", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Luminous Noble Topaz", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Lustrous Star of Elune", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Potent Noble Topaz", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Radiant Talasite", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Rigid Dawnstone", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Royal Nightseye", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Runed Living Ruby", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Shifting Nightseye", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Smooth Dawnstone", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Sovereign Nightseye", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Solid Star of Elune", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Sparkling Star of Elune", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Stormy Star of Elune", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Subtle Living Ruby", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Teardrop Living Ruby", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Thick Dawnstone", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Bold Living Ruby", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Khorium Band of Shadows", 350, nil, "BoP mob drop from Dark Conclave Shadowmancers in Shadowmoon Valley.  Only drops for jewelcrafters" );
	addTradeSkill( "Khorium Band of Frost", 355, nil, "BoP mob drop from Coilfang Sorceresses in The Steamvault" );
	addTradeSkill( "Khorium Inferno Band", 355, nil, "BoP mob drop from Darkweaver Syth in Sethekk Halls" );
	addTradeSkill( "Delicate Eternium Ring", 355, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Thick Felsteel Necklace", 355, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Living Ruby Pendant", 355, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Khorium Band of Leaves", 360, nil, "BoP mob drop from Vekh'nir Dreadhawks in Blade's Edge Mountains" );
	addTradeSkill( "Pendant of Frozen Flame", 360, nil, "You can buy this from Alurmi in Tanaris when you are revered with Keepers of Time" );
	addTradeSkill( "Pendant of Thawing", 360, nil, "You can buy this from Nakodu in Shattrath City when you are revered with Lower City" );
	addTradeSkill( "Pendant of Withering", 360, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Pendant of Shadow's End", 360, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Pendant of the Null Rune", 360, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are revered with The Consortium" );
	addTradeSkill( "Braided Eternium Chain", 360, nil, "World Drop (Buy on HA)" );
	addTradeSkill( "Eye of the Night", 360, nil, "World Drop (Buy on HA)" );
	addTradeSkill( "Ring of Arcane Shielding", 360, nil, "You can buy this from Almaador in Shattrath when you are honored with The Sha'tar" );
	addTradeSkill( "Arcane Khorium Band", 365, nil, "BoP mob drop from Mageslayers in Netherstorm" );
	addTradeSkill( "Blazing Eternium Band", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Embrace of the Dawn", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Chain of the Twilight Owl", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Bracing Earthstorm Diamond", 365, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are revered with The Consortium" );
	addTradeSkill( "Brutal Earthstorm Diamond", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Insightful Earthstorm Diamond", 365, nil, "You can buy this from Almaador in Shattrath when you are friendly with The Sha'tar" );
	addTradeSkill( "Powerful Earthstorm Diamond", 365, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Tenacious Earthstorm Diamond", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Destructive Skyfire Diamond", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Enigmatic Skyfire Diamond", 365, nil, "You can buy this from Alurmi in Tanaris when you are honored with Keepers of Time" );
	addTradeSkill( "Mystical Skyfire Diamond", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Swift Skyfire Diamond", 365, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Coronet of the Verdant Flame", 370, nil, "BoP mob drop from Sunseeker Botanists in The Botanica" );
	addTradeSkill( "Circlet of Arcane Might", 370, nil, "BoP mob drop from Epoch Hunter in Old Hillsbrad Foothills" );
	addTradeSkill( "Figurine - Felsteel Boar", 370, nil, "You can buy this from Nakodu in Shattrath City when you are revered with Lower City" );
	addTradeSkill( "Figurine - Dawnstone Crab", 370, nil, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are revered with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are revered with Thrallmar" );
	addTradeSkill( "Figurine - Living Ruby Serpent", 370, nil, "You can buy this from Alurmi in Tanaris when you are revered with Keepers of Time" );
	addTradeSkill( "Figurine - Talasite Owl", 370, nil, "You can buy this from Almaador in Shattrath when you are revered with The Sha'tar" );
	addTradeSkill( "Figurine - Nightseye Panther", 370, nil, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are revered with Cenarion Expedition" );
	addTradeSkill( "The Frozen Eye", 375, nil, "You can purchase this from Koren in Karazhan when you are honored with The Violet Eye" );
	addTradeSkill( "The Natural Ward", 375, nil, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are exalted with Cenarion Expedition" );
	
end

-- Initializes the array adding all LeatherWorking recipes.  As of 2.2 there are

function AckisRecipeList:InitLeatherWorking()

	AckisRecipeList.InitializeRecipeArray();

	addTradeSkill( "Handstitched Leather Boots", 1, nil, "Trainer" );
	addTradeSkill( "Light Armor Kit", 1, nil, "Trainer" );
	addTradeSkill( "Light Leather", 1, nil, "Trainer" );
	addTradeSkill( "Handstitched Leather Vest", 1, nil, "Trainer" );
	addTradeSkill( "Handstitched Leather Cloak", 1, nil, "Trainer" );
	addTradeSkill( "Handstitched Leather Bracers", 1, nil, "Trainer" );
	addTradeSkill( "Handstitched Leather Pants", 15, nil, "Trainer" );
	addTradeSkill( "Handstitched Leather Belt", 25, nil, "Trainer" );
	addTradeSkill( "Light Leather Quiver", 30, nil, "Trainer" );
	addTradeSkill( "Small Leather Ammo Pouch", 30, nil, "Trainer" );
	addTradeSkill( "Cured Light Hide", 35, nil, "Trainer" );
	addTradeSkill( "Rugged Leather Pants", 35, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Kodo Hide Bag", 40, nil, "Reward from quest (Kodo Hide Bag) obtained from Veren Tallstrider in Thunder Bluff", "Horde" );
	addTradeSkill( "Embossed Leather Vest", 40, nil, "Trainer" );
	addTradeSkill( "Embossed Leather Gloves", 55, nil, "Trainer" );
	addTradeSkill( "Embossed Leather Boots", 55, nil, "Trainer" );
	addTradeSkill( "Embossed Leather Cloak", 60, nil, "Trainer" );
	addTradeSkill( "White Leather Jerkin", 60, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Embossed Leather Pants", 75, nil, "Trainer" );
	addTradeSkill( "Fine Leather Gloves", 75, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Fine Leather Belt", 80, nil, "Trainer" );
	addTradeSkill( "Fine Leather Cloak", 85, nil, "Trainer" );
	addTradeSkill( "Fine Leather Tunic", 85, nil, "Trainer" );
	addTradeSkill( "Murloc Scale Belt", 90, nil, "VENDOR" );
	addTradeSkill( "Deviate Scale Cloak", 90, nil, "VENDOR" );
	addTradeSkill( "Moonglow Vest", 90, nil, "Reward from quest (Moonglow Vest) obtained from Lotherias in Darnassus", "Alliance" );
	addTradeSkill( "Fine Leather Boots", 90, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Light Leather Bracers", 70, nil, "Trainer" );
	addTradeSkill( "Murloc Scale Breastplate", 95, nil, "VENDOR" );
	addTradeSkill( "Light Leather Pants", 95, nil, "Trainer" );
	addTradeSkill( "Hillman's Leather Vest", 100, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Cured Medium Hide", 100, nil, "Trainer" );
	addTradeSkill( "Black Whelp Cloak", 100, nil, "VENDOR" );
	addTradeSkill( "Medium Leather", 100, nil, "Trainer" );
	addTradeSkill( "Black Whelp Tunic", 100, nil, "VENDOR" );
	addTradeSkill( "Medium Armor Kit", 100, nil, "Trainer" );
	addTradeSkill( "Dark Leather Boots", 100, nil, "Trainer" );
	addTradeSkill( "Dark Leather Tunic", 100, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Fine Leather Pants", 105, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Deviate Scale Gloves", 105, nil, "VENDOR" );
	addTradeSkill( "Dark Leather Cloak", 110, nil, "Trainer" );
	addTradeSkill( "Dark Leather Pants", 115, nil, "Trainer" );
	addTradeSkill( "Deviate Scale Belt", 115, nil, "Reward from quest (Deviate Eradication) obtained from Ebru in The Wailing Caverns" );
	addTradeSkill( "Dark Leather Gloves", 120, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Hillman's Belt", 120, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Red Whelp Gloves", 120, nil, "VENDOR");
	addTradeSkill( "Nimble Leather Gloves", 120, nil, "Trainer" );
	addTradeSkill( "Toughened Leather Armor", 120, nil, "Trainer" );
	addTradeSkill( "Dark Leather Belt", 125, nil, "Trainer" );
	addTradeSkill( "Fletcher's Gloves", 125, nil, "Trainer" );
	addTradeSkill( "Hillman's Shoulders", 130, nil, "Trainer" );
	addTradeSkill( "Toughened Leather Gloves", 135, nil, "Trainer" );
	addTradeSkill( "Herbalist's Gloves", 135, nil, "VENDOR" );
	addTradeSkill( "Earthen Leather Shoulders", 135, nil, "VENDOR" );
	addTradeSkill( "Dark Leather Shoulders", 140, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Pilferer's Gloves", 140, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Hillman's Leather Gloves", 145, nil, "Trainer" );
	addTradeSkill( "Heavy Earthen Gloves", 145, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Hillman's Cloak", 150, nil, "Trainer" );
	addTradeSkill( "Barbaric Gloves", 150, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Cured Heavy Hide", 150, nil, "Trainer" );
	addTradeSkill( "Heavy Armor Kit", 150, nil, "Trainer" );
	addTradeSkill( "Heavy Quiver", 150, nil, "Trainer" );
	addTradeSkill( "Heavy Leather Ammo Pouch", 150, nil, "Trainer" );
	addTradeSkill( "Heavy Leather", 150, nil, "Trainer" );
	addTradeSkill( "Heavy Leather Ball", 150, nil, "VENDOR" );
	addTradeSkill( "Green Leather Armor", 155, nil, "VENDOR" );
	addTradeSkill( "Barbaric Bracers", 155, nil, "VENDOR" );
	addTradeSkill( "Green Leather Belt", 160, nil, "Trainer" );
	addTradeSkill( "Guardian Pants", 160, nil, "Trainer" );
	addTradeSkill( "Raptor Hide Belt", 165, nil, "VENDOR" );
	addTradeSkill( "Raptor Hide Harness", 165, nil, "VENDOR - horde only" );
	addTradeSkill( "Dusky Leather Leggings", 165, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Guardian Belt", 170, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Thick Murloc Armor", 170, nil, "VENDOR" );
	addTradeSkill( "Barbaric Leggings", 170, nil, "VENDOR" );
	addTradeSkill( "Guardian Armor", 175, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Barbaric Shoulders", 175, nil, "Trainer" );
	addTradeSkill( "Dusky Leather Armor", 175, nil, "Trainer" );
	addTradeSkill( "Green Whelp Armor", 175, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Green Leather Bracers", 180, nil, "Trainer" );
	addTradeSkill( "Frost Leather Cloak", 180, nil, "Trainer" );
	addTradeSkill( "Gem-studded Leather Belt", 185, nil, "VENDOR" );
	addTradeSkill( "Guardian Cloak", 185, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Dusky Bracers", 185, nil, "Trainer" );
	addTradeSkill( "Barbaric Harness", 190, nil, "Trainer" );
	addTradeSkill( "Murloc Scale Bracers", 190, nil, "VENDOR" );
	addTradeSkill( "Guardian Gloves", 190, nil, "Trainer" );
	addTradeSkill( "Green Whelp Bracers", 190, nil, "VENDOR" );
	addTradeSkill( "Gloves of the Greatfather", 190, nil, "You can get this randomly as a reward from a Feast of Winter Veil quest." );
	addTradeSkill( "Guardian Leather Bracers", 195, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Dusky Belt", 195, nil, "Trainer" );
	addTradeSkill( "Barbaric Belt", 200, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Dusky Boots", 200, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Swift Boots", 200, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Cured Thick Hide", 200, nil, "Trainer" );
	addTradeSkill( "Thick Armor Kit", 200, nil, "Trainer" );
	addTradeSkill( "Comfortable Leather Hat", 200, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Thick Leather", 200, nil, "Trainer" );
	addTradeSkill( "Shadowskin Gloves", 200, nil, "VENDOR" );
	addTradeSkill( "Nightscape Tunic", 205, nil, "Trainer" );
	addTradeSkill( "Nightscape Headband", 205, nil, "Trainer" );
	addTradeSkill( "Turtle Scale Gloves", 205, nil, "VENDOR" );
	addTradeSkill( "Turtle Scale Breastplate", 210, nil, "Trainer" );
	addTradeSkill( "Nightscape Shoulders", 210, nil, "VENDOR" );
	addTradeSkill( "Turtle Scale Bracers", 210, nil, "Trainer" );
	addTradeSkill( "Big Voodoo Robe", 215 );
	addTradeSkill( "Tough Scorpid Breastplate", 220, nil, "Mob Drop: Wastewander Bandit (Tanaris)" );
	addTradeSkill( "Wild Leather Shoulders", 220, nil, "Reward from quest (Wild Leather Shoulders) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas");
	addTradeSkill( "Big Voodoo Mask", 220, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Tough Scorpid Bracers", 220, nil, "Mob Drop: Wastewander Shadow Mage (Tanaris)" );
	addTradeSkill( "Tough Scorpid Gloves", 225, nil, "Mob Drop: Wastewander Thief (Tanaris)" );
	addTradeSkill( "Wild Leather Vest", 225, nil, "Reward from quest (Wild Leather Vest) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas");
	addTradeSkill( "Wild Leather Helmet", 225, nil, "Reward from quest (Wild Leather Helmet) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas");
	addTradeSkill( "Quickdraw Quiver", 225, nil, "Trainer" );
	addTradeSkill( "Thick Leather Ammo Pouch", 225, nil, "Trainer" );
	addTradeSkill( "Nightscape Pants", 230, nil, "Trainer" );
	addTradeSkill( "Turtle Scale Helm", 230, nil, "Trainer" );
	addTradeSkill( "Tough Scorpid Boots", 235, nil, "Mob Drop: Wastewander Rogue (Tanaris)" );
	addTradeSkill( "Turtle Scale Leggings", 235, nil, "Trainer" );
	addTradeSkill( "Nightscape Boots", 235, nil, "Trainer" );
	addTradeSkill( "Big Voodoo Pants", 240, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Big Voodoo Cloak", 240, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Tough Scorpid Shoulders", 240, nil, "Mob Drop: Andre Firebeard and Wastewander Scofflaw (Tanaris)" );
	addTradeSkill( "Wild Leather Boots", 245, nil, "Reward from quest (Wild Leather Boots) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas" );
	addTradeSkill( "Tough Scorpid Leggings", 245, nil, "Mob Drop: Wastewander Rogue (Tanaris)" );
	addTradeSkill( "Tough Scorpid Helm", 250, nil, "Mob Drop: Andre Firebeard and Wastewander Scofflaw (Tanaris)" );
	addTradeSkill( "Wild Leather Leggings", 250, nil, "Reward from quest (Wild Leather Leggings) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas" );
	addTradeSkill( "Wild Leather Cloak", 250, nil, "Reward from quest (Master of the Wild Leather) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas" );
	addTradeSkill( "Cured Rugged Hide", 250, nil, "Trainer" );
	addTradeSkill( "Rugged Armor Kit", 250, nil, "Trainer" );
	addTradeSkill( "Rugged Leather", 250, nil, "Trainer" );
	addTradeSkill( "Heavy Scorpid Bracers", 255, nil, "VENDOR" );
	addTradeSkill( "Wicked Leather Gauntlets", 260, nil, "VENDOR");  
	addTradeSkill( "Heavy Scorpid Vest", 265, nil, "Mob Drop: Portal Seeker (Blasted Lands)");
	addTradeSkill( "Wicked Leather Bracers", 265, nil, "Mob Drop: Legashi Rogue (Azshara)");
	addTradeSkill( "Runic Leather Gauntlets", 270, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Heavy Scorpid Gauntlets", 275, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Runic Leather Bracers", 275, nil, "Mob Drop: Jaedenar Cultist (Felwood)" );
	addTradeSkill( "Heavy Scorpid Belt", 280, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Wicked Leather Headband", 280, nil, "Mob Drop: JadefireTrickster (Felwood)" );
	addTradeSkill( "Runic Leather Belt", 280, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Heavy Scorpid Leggings", 285, nil, "Mob Drop: Blackrock Slayer (Blackrock Mountain and Burning Steppes)" );
	addTradeSkill( "Runic Leather Headband", 290, nil, "VENDOR" );
	addTradeSkill( "Wicked Leather Pants", 290, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Might of the Timbermaw", 290, nil, "You can buy this from Meilosh in Felwood when you are honored with Timbermaw Hold"  );
	addTradeSkill( "Dawn Treaders", 290, nil, "You can buy this from an Argent Dawn Quartermaster when you are honored with Argent Dawn" );
	addTradeSkill( "Heavy Scorpid Helm", 295, nil, "VENDOR" );
	addTradeSkill( "Runic Leather Pants", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Wicked Leather Belt", 300, nil, "Mob Drop: Ghoul Ravener (Stratholme)" );
	addTradeSkill( "Heavy Scorpid Shoulders", 300, nil, "Mob Drop: Blackrock Battlemaster (Burning Steppes)" );
	addTradeSkill( "Runic Leather Armor", 300, nil, "Mob Drop: Scholomance Dark Summoner (Scholomance)" );
	addTradeSkill( "Wicked Leather Armor", 300, nil, "Mob Drop: Spectral Researcher (Scholomance)" );
	addTradeSkill( "Runic Leather Shoulders", 300, nil, "Mob Drop: Crimson Battle Mage (Stratholme)" );
	addTradeSkill( "Core Armor Kit", 300, nil, "Mob Drop: Molten Core Bosses - binds when picked up" );
	addTradeSkill( "Girdle of Insight", 300, nil, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Warlock, Gordok Bushwacker and Gordok Reaver (Dire Maul)" );
	addTradeSkill( "Mongoose Boots", 300, nil, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Warlock, Gordok Bushwacker and Gordok Reaver (Dire Maul)" );
	addTradeSkill( "Swift Flight Bracers", 300, nil, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Warlock, Gordok Bushwacker and Gordok Reaver (Dire Maul)" );
	addTradeSkill( "Timbermaw Brawlers", 300, nil, "You can buy this from Meilosh in Felwood when you are revered with Timbermaw Hold"  );
	addTradeSkill( "Golden Mantle of the Dawn", 300, nil, "You can buy this from an Argent Dawn Quartermaster when you are revered with Argent Dawn"  );
	addTradeSkill( "Lava Belt", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Blood Tiger Breastplate", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Blood Tiger Shoulders", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Primal Batskin Bracers", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are friendly with Zandalar Tribe" );
	addTradeSkill( "Primal Batskin Gloves", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Primal Batskin Jerkin", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Spitfire Bracers", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are friendly with Cenarion Circle" );
	addTradeSkill( "Spitfire Gauntlets", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are honored with Cenarion Circle" );
	addTradeSkill( "Spitfire Breastplate", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Sandstalker Bracers", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are friendly with Cenarion Circle" );
	addTradeSkill( "Sandstalker Gauntlets", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are honored with Cenarion Circle" );
	addTradeSkill( "Sandstalker Breastplate", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Onyxia Scale Cloak", 300, nil, "Reward from followup quest (The Journey Has Just Begun) after turning in Head of Onyxia" );


	addTradeSkill( "Gordok Ogre Suit", 300, nil, "Can learn recipe after completing quest (The Gordok Ogre Suit) obtained from Knot Thimblejack from Dire Maul" );
	addTradeSkill( "Icy Scale Bracers", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Icy Scale Breastplate", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are exalted with Argent Dawn" );
	addTradeSkill( "Icy Scale Gauntlets", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Polar Bracers", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Polar Gloves", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Polar Tunic", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are exalted with Argent Dawn" );
	addTradeSkill( "Bramblewood Belt", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are friendly with Cenarion Circle"  );
	addTradeSkill( "Bramblewood Boots", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are honored with Cenarion Circle"  );
	addTradeSkill( "Bramblewood Helm", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are revered with Cenarion Circle" );

	addTradeSkill( "Green Dragonscale Gauntlets", 280, nil, "Trainer" );
	addTradeSkill( "Dragonscale Gauntlets", 225, nil, "Trainer" );
	addTradeSkill( "Dragonscale Breastplate", 255, nil, "Trainer" );
	addTradeSkill( "Green Dragonscale Breastplate", 260, nil, "VENDOR" );
	addTradeSkill( "Dragonstrike Leggings", 260, "Dragonscale", "Trainer" );
	addTradeSkill( "Blackstorm Leggings", 260, "Elemental", "Trainer" );
	addTradeSkill( "Wildfeather Leggings", 260, "Tribal", "Trainer" );

	addTradeSkill( "Green Dragonscale Leggings" , 270, nil, "Mob Drop: Murk Worm (The Temple of Atal'Hakkar)" );
	addTradeSkill( "Blue Dragonscale Breastplate", 285, nil, "VENDOR" );
	addTradeSkill( "Black Dragonscale Breastplate", 290, nil, "VENDOR" );
	addTradeSkill( "Blue Dragonscale Shoulders", 295, nil, "Mob Drop: Cliff Breaker (Azshara)" );
	addTradeSkill( "Red Dragonscale Breastplate", 300, nil, "Mob Drop: General Drakkisath (Hall of Blackhand)" );
	addTradeSkill( "Black Dragonscale Leggings", 300, nil, "Mob Drop: Anvilrage Captain (Blackrock Depths)" );
	addTradeSkill( "Black Dragonscale Shoulders", 300, nil, "Mob Drop : Anvilrage Captain (Blackrock Depths)" );
	addTradeSkill( "Black Dragonscale Boots", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Chromatic Cloak", 300, nil, "Knot Thimblejack's Cache (Dire Maul)" );
	addTradeSkill( "Chromatic Gauntlets", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Blue Dragonscale Leggings", 300, nil, "Trainer" );
	addTradeSkill( "Dreamscale Breastplate", 300, nil, "You can buy this from Aendel Windspear in Silithus when you are exalted with Cenarion Circle"  );

	addTradeSkill( "Gauntlets of the Sea", 230, nil, "Trainer" );
	addTradeSkill( "Helm of Fire", 250, nil, "Trainer" );
	addTradeSkill( "Volcanic Leggings", 270, nil, "Mob Drop: Firegut Brute (Burning Steppes)" );
	addTradeSkill( "Living Shoulders", 270, nil, "VENDOR" );
	addTradeSkill( "Stormshroud Pants", 275, nil, "VENDOR" );
	addTradeSkill( "Volcanic Breastplate", 285, nil, "Mob Drop: Firebrand Grunt (Hall of Blackhand)" );
	addTradeSkill( "Living Leggings", 285, nil, "Mob Drop: Deadwood Shaman (Felwood)" );
	addTradeSkill( "Stormshroud Armor", 285, nil, "Mob Drop: Arkkoran Oracle (Azshara)" );
	addTradeSkill( "Stormshroud Shoulders", 295, nil, "Son or Arkkoroc (Azshara)" );
	addTradeSkill( "Stormshroud Gloves", 300, nil, "Mob Drop: The Windreaver (Silithus), Princess Tempestria (Winterspring)" );
	addTradeSkill( "Living Breastplate", 300, nil, "Mob Drop: Decaying Horror (Western Plaguelands)" );
	addTradeSkill( "Volcanic Shoulders", 300, nil, "Mob Drop: Firebrand Legionnaire (Hall of Blackhand)" );
	addTradeSkill( "Molten Helm", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are friendly with Thorium Brotherhood" );
	addTradeSkill( "Shifting Cloak", 300, nil, "Knot Thimblejack's Cache (Dire Maul)" );
	addTradeSkill( "Molten Belt", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are revered with Thorium Brotherhood" );

	addTradeSkill( "Wolfshead Helm", 225, nil, "Trainer" );
	addTradeSkill( "Feathered Breastplate", 250, nil, "Trainer" );
	addTradeSkill( "Chimeric Gloves", 265, nil, "VENDOR" );
	addTradeSkill( "Ironfeather Shoulders", 270, nil, "VENDOR" );
	addTradeSkill( "Chimeric Boots", 275, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Frostsaber Boots", 275, nil, "VENDOR" );
	addTradeSkill( "Warbear Harness", 275, nil, "You can buy this from Meilosh in Felwood when you are friendly with Timbermaw Hold" );
	addTradeSkill( "Chimeric Leggings", 280, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Frostsaber Leggings", 285, nil, "Mob Drop: Winterfall Den Watcher (Winterspring)" );
	addTradeSkill( "Warbear Woolies", 285, nil, "You can buy this from Meilosh in Felwood when you are friendly with Timbermaw Hold" );
	addTradeSkill( "Chimeric Vest", 290, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Devilsaur Gauntlets", 290, nil, "VENDOR" );
	addTradeSkill( "Ironfeather Breastplate", 290, nil, "Mob Drop: Vilebranch Hideskinner (The Hinterlands)" );
	addTradeSkill( "Frostsaber Gloves", 295, nil, "Mob Drop: Winterfall Totemic (Winterspring)" );
	addTradeSkill( "Corehound Boots", 295, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are friendly with Thorium Brotherhood" );
	addTradeSkill( "Devilsaur Leggings", 300, nil, "Mob Drop: Cloned Ooze and Muculent Ooze (Ungoro Crater)" );
	addTradeSkill( "Frostsaber Tunic", 300, nil, "Mob Drop: Winterfall Ursa (Winterspring)" );
	addTradeSkill( "Hide of the Wild", 300, nil, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Corehound Belt", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are revered with Thorium Brotherhood" );

	addTradeSkill( "Comfortable Insoles", 300, nil, "VENDOR" );
	addTradeSkill( "Felscale Gloves", 300, nil, "Trainer" );
	addTradeSkill( "Knothide Armor Kit", 300, nil, "Trainer" );
	addTradeSkill( "Knothide Leather", 300, nil, "Trainer" );
	addTradeSkill( "Scaled Draenic Pants", 300, nil, "Trainer" );
	addTradeSkill( "Thick Draenic Pants", 300, nil, "Trainer" );
	addTradeSkill( "Wild Draenish Boots", 300, nil, "Trainer" );
	addTradeSkill( "Felscale Boots", 310, nil, "Trainer" );
	addTradeSkill( "Scaled Draenic Gloves", 310, nil, "Trainer" );
	addTradeSkill( "Wild Draenish Gloves", 310, nil, "Trainer" );
	addTradeSkill( "Thick Draenic Pants", 315, nil, "Trainer" );
	addTradeSkill( "Felscale Pants", 320, nil, "Trainer" );
	addTradeSkill( "Thick Draenic Boots", 320, nil, "Trainer" );
	addTradeSkill( "Wild Draenish Leggings", 320, nil, "Trainer" );
	addTradeSkill( "Heavy Knothide Leather", 325, nil, "VENDOR" );
	addTradeSkill( "Vindicator's Armor Kit", 325, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Magister's Armor Kit", 325, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Scaled Draenic Vest", 325, nil, "Trainer" );
	addTradeSkill( "Reinforced Mining Bag", 325, nil, "Alliance can buy this from Trader Narasu in Nagrand when they are honored with Kurenai, Horde from Provisioner Nasala when they are honored with Mag'har" );

	addTradeSkill( "Thick Draenic Vest", 330, nil, "Trainer" );
	addTradeSkill( "Wild Draenish Vest", 330, nil, "Trainer" );
	addTradeSkill( "Living Crystal Breastplate", 330, nil, "Trainer" );
	addTradeSkill( "Golden Dragonstrike Breastplate", 330, "Dragonscale", "Trainer" );
	addTradeSkill( "Primalstorm Breastplate", 330, "Elemental", "Trainer" );
	addTradeSkill( "Living Crystal Breastplate", 330, "Tribal", "Trainer" );

	addTradeSkill( "Felscale Breastplate", 335, nil, "Trainer" );
	addTradeSkill( "Scaled Draenic Boots", 335, nil, "Trainer" );
	addTradeSkill( "Cobrahide Leg Armor", 335, nil, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are honored with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are honored with Thrallmar" );
	addTradeSkill( "Clefthide Leg Armor", 335, nil, "You can buy this from Aendel Windspear in Silithus when you are honored with Cenarion Circle"  );
	addTradeSkill( "Fel Leather Gloves", 340, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are friendly with The Consortium" );
	addTradeSkill( "Netherfury Belt", 340, nil, "Alliance can buy this from Trader Narasu in Nagrand when they are friendly with Kurenai, Horde from Provisioner Nasala when they are friendly with Mag'har" );
	addTradeSkill( "Netherfury Leggings", 340, nil, "Alliance can buy this from Trader Narasu in Nagrand when they are honored with Kurenai, Horde from Provisioner Nasala when they are honored with Mag'har" );
	addTradeSkill( "Shadow Armor Kit", 340, nil, "BoP mob drop from Time-Lost Shadowmages in Sethekk Halls" );
	addTradeSkill( "Flame Armor Kit", 340, nil, "BoP mob drop from Gargantuan Abyssals in The Arcatraz" );
	addTradeSkill( "Nature Armor Kit", 340, nil, "BoP mob drop from Mennu the Betrayer in The Slave Pens" );
	addTradeSkill( "Arcane Armor Kit", 340, nil, "BoP mob drop from Chrono Lord Deja in The Black Morass" );
	addTradeSkill( "Frost Armor Kit", 340, nil, "BoP mob drop from Hydromancer Thespia in The Steamvault" );
	addTradeSkill( "Drums of War", 340, nil, "Trainer" );
	addTradeSkill( "Drums of Speed", 345, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Riding Crop", 350, nil, "Vendor" );
	addTradeSkill( "Stylin' Purple Hat", 350, nil, "BoP mob drop from Blackheart the Inciter in Shadow Labyrinth" );
	addTradeSkill( "Stylin' Adventure Hat", 350, nil, "BoP mob drop from Durnholde Riflemen in Old Hillsbrad Foothills" );
	addTradeSkill( "Stylin' Jungle Hat", 350, nil, "BoP mob drop from Rift Lords and Rift Keepers in The Black Morass" );
	addTradeSkill( "Stylin' Crimson Hat", 350, nil, "BoP mob drop from Sethekk Ravenguard in Sethekk Halls" );
	addTradeSkill( "Fel Leather Boots", 350, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Fel Leather Leggings", 350, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are revered with The Consortium" );
	addTradeSkill( "Felstalker Belt", 350, nil, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are friendly with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are friendly with Thrallmar" );
	addTradeSkill( "Netherfury Boots", 350, nil, "Alliance can buy this from Trader Narasu in Nagrand when they are revered with Kurenai, Horde from Provisioner Nasala when they are revered with Mag'har" );
	addTradeSkill( "Enchanted Felscale Boots", 350, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Enchanted Felscale Gloves", 350, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Enchanted Felscale Leggings", 350, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are exalted with Scryers" );
	addTradeSkill( "Flamescale Belt", 350, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Flamescale Boots", 350, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Flamescale Leggings", 350, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );
	addTradeSkill( "Enchanted Clefthoof Boots", 350, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Enchanted Clefthoof Gloves", 350, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Enchanted Clefthoof Leggings", 350, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are exalted with Scryers" );
	addTradeSkill( "Blastguard Belt", 350, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Blastguard Boots", 350, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Blastguard Pants", 350, 350, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );
	addTradeSkill( "Drums of Restoration", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Heavy Clefthoof Leggings", 355, nil, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Heavy Clefthoof Boots", 355, nil, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are friendly with Cenarion Expedition" );
	addTradeSkill( "Heavy Clefthoof Vest", 360, nil, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Felstalker Bracer", 360, nil, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are honored with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are honored with Thrallmar" );
	addTradeSkill( "Felstalker Breastplate", 360, nil, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are honored with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are honored with Thrallmar" );
	addTradeSkill( "Drums of Battle", 365, nil, "You can buy this from Almaador in Shattrath when you are exalted with The Sha'tar" );
	addTradeSkill( "Nethercobra Leg Armor", 365, nil, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are exalted with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are exalted with Thrallmar" );
	addTradeSkill( "Nethercleft Leg Armor", 365, nil, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are exalted with Cenarion Expedition" );
	addTradeSkill( "Cobrascale Gloves", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Cobrascale Hood", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Earthen Netherscale Boots", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Gloves of the Living Touch", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Hood of Primal Life", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Living Dragonscale Helm", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Netherdrake Gloves", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Netherdrake Helm", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Thick Netherscale Breastplate", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Windslayer Wraps", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Windscale Hood", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Windstrike Gloves", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Drums of Panic", 370, nil, "You can buy this from Alurmi in Tanaris when you are exalted with Keepers of Time" );

	addTradeSkill( "Ebon Netherscale Belt", 375, "Dragonscale", "Trainer" );
	addTradeSkill( "Ebon Netherscale Bracers", 375, "Dragonscale", "Trainer" );
	addTradeSkill( "Ebon Netherscale Breastplate", 375, "Dragonscale", "Trainer" );
	addTradeSkill( "Netherstrike Belt", 375, "Dragonscale", "Trainer" );
	addTradeSkill( "Netherstrike Bracers", 375, "Dragonscale", "Trainer" );
	addTradeSkill( "Netherstrike Breastplate", 375, "Dragonscale", "Trainer" );

	addTradeSkill( "Primalstrike Belt", 375, "Elemental", "Trainer" );
	addTradeSkill( "Primalstrike Bracers", 375, "Elemental", "Trainer" );
	addTradeSkill( "Primalstrike Vest", 375, "Elemental", "Trainer" );

	addTradeSkill( "Windhawk Belt", 375, "Tribal", "Trainer" );
	addTradeSkill( "Windhawk Bracers", 375, "Tribal", "Trainer" );
	addTradeSkill( "Windhawk Hauberk", 375, "Tribal", "Trainer" );
end

-- Initializes the array adding all Rogue Poisons.  As of 2.2 there are

function AckisRecipeList:InitRoguePoison()

	AckisRecipeList.InitializeRecipeArray();

	addTradeSkill( "Crippling Poison", 20, nil, "Trainer" );
	addTradeSkill( "Crippling Poison II", 50, nil, "Trainer" );
	addTradeSkill( "Mind-numbing Poison", 24, nil, "Trainer" );
	addTradeSkill( "Mind-numbing Poison II", 38, nil, "Trainer" );
	addTradeSkill( "Mind-numbing Poison III", 52, nil, "Trainer" );
	addTradeSkill( "Instant Poison", 20, nil, "Trainer" );
	addTradeSkill( "Instant Poison II", 28, nil, "Trainer" );
	addTradeSkill( "Instant Poison III", 36, nil, "Trainer" );
	addTradeSkill( "Instant Poison IV", 44, nil, "Trainer" );
	addTradeSkill( "Instant Poison V", 52, nil, "Trainer" );
	addTradeSkill( "Instant Poison VI", 60, nil, "Trainer" );
	addTradeSkill( "Deadly Poison", 30, nil, "Trainer" );
	addTradeSkill( "Deadly Poison II", 38, nil, "Trainer" );
	addTradeSkill( "Deadly Poison III", 46, nil, "Trainer" );
	addTradeSkill( "Deadly Poison IV", 54, nil, "Trainer" );
	addTradeSkill( "Deadly Poison V", 60, nil, "Trainer" );
	addTradeSkill( "Wound Poison", 32, nil, "Trainer" );
	addTradeSkill( "Wound Poison II", 40, nil, "Trainer" );
	addTradeSkill( "Wound Poison III", 48, nil, "Trainer" );
	addTradeSkill( "Wound Poison IV", 56, nil, "Trainer" );
	addTradeSkill( "Blinding Powder", 34, nil, "Trainer" );
	
end

-- Initializes the array adding all Tailoring recipes.  As of 2.2 there are

function AckisRecipeList:InitTailoring()

	AckisRecipeList.InitializeRecipeArray();

	addTradeSkill( "Bolt of Linen Cloth", 1, nil, "Trainer" );
	addTradeSkill( "Linen Cloak", 1, nil, "Trainer" );
	addTradeSkill( "White Linen Shirt", 1, nil, "Trainer" );
	addTradeSkill( "Brown Linen Shirt", 1, nil, "Trainer" );
	addTradeSkill( "Simple Linen Pants", 1, nil, "Trainer" );
	addTradeSkill( "Brown Linen Vest", 10, nil, "Trainer" );
	addTradeSkill( "Linen Belt", 15, nil, "Trainer" );
	addTradeSkill( "Simple Linen Boots", 20, nil, "Trainer" );
	addTradeSkill( "Brown Linen Pants", 30, nil, "Trainer" );
	addTradeSkill( "Brown Linen Robe", 30, nil, "Trainer" );
	addTradeSkill( "White Linen Robe", 30, nil, "Trainer" );
	addTradeSkill( "Heavy Linen Gloves", 35, nil, "Trainer" );
	addTradeSkill( "Red Linen Robe", 40, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Red Linen Shirt", 40, nil, "Trainer" );
	addTradeSkill( "Blue Linen Shirt", 40, nil, "Trainer" );
	addTradeSkill( "Simple Dress", 40, nil, "Trainer" );
	addTradeSkill( "Linen Bag", 45, nil, "Trainer" );
	addTradeSkill( "Blue Linen Vest", 55, nil, "VENDOR" );
	addTradeSkill( "Red Linen Vest", 55, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Reinforced Linen Cape", 60, nil, "Trainer" );
	addTradeSkill( "Green Linen Bracers", 60, nil, "Trainer" );
	addTradeSkill( "Linen Boots", 65, nil, "Trainer");
	addTradeSkill( "Red Linen Bag", 70, nil, "VENDOR" );
	addTradeSkill( "Blue Linen Robe", 70, nil, "VENDOR" );
	addTradeSkill( "Bolt of Woolen Cloth", 75, nil, "Trainer" );
	addTradeSkill( "Woolen Cape", 75, nil, "Trainer" );
	addTradeSkill( "Simple Kilt", 75, nil, "Trainer" );
	addTradeSkill( "Soft-soled Linen Boots", 80, nil, "Trainer" );
	addTradeSkill( "Woolen Bag", 80, nil, "Trainer" );
	addTradeSkill( "Green Woolen Vest", 85, nil, "Trainer" );
	addTradeSkill( "Heavy Woolen Gloves", 85, nil, "Trainer" );
	addTradeSkill( "Pearl-clasped Cloak", 90, nil, "Trainer" );
	addTradeSkill( "Barbaric Linen Vest", 90, nil, "Trainer" );
	addTradeSkill( "Green Linen Shirt", 90, nil, "Trainer" );
	addTradeSkill( "Handstitched Linen Britches", 90, nil, "Trainer" );
	addTradeSkill( "Woolen Boots", 95, nil, "Trainer" );
	addTradeSkill( "Red Woolen Boots", 95, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Green Woolen Bag", 95, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Gray Woolen Shirt", 100, nil, "Trainer" );
	addTradeSkill( "Heavy Woolen Cloak", 100, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Blue Overalls", 100, nil, "VENDOR" );
	addTradeSkill( "Gray Woolen Robe", 105, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Double-stitched Woolen Shoulders", 110, nil, "Trainer" );
	addTradeSkill( "Heavy Woolen Pants", 110, nil, "Trainer" );
	addTradeSkill( "White Woolen Dress", 110, nil, "Trainer" );
	addTradeSkill( "Red Woolen Bag", 115, nil, "VENDOR" );
	addTradeSkill( "Greater Adept's Robe", 115, nil, "Alliance - Limited Supply from Rann Flamespinner (Loch Modan [36,46])" );
	addTradeSkill( "Reinforced Woolen Shoulders", 120, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Stylish Blue Shirt", 120, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Stylish Green Shirt", 120, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Colorful Kilt", 120, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Bolt of Silk Cloth", 125, nil, "Trainer" );
	addTradeSkill( "Phoenix Pants", 125, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Spidersilk Boots", 125, nil, "Trainer" );
	addTradeSkill( "Stylish Red Shirt", 125, nil, "Trainer" );
	addTradeSkill( "Phoenix Gloves", 125, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Gloves of Meditation", 130, nil, "Trainer" );
	addTradeSkill( "Bright Yellow Shirt", 135, nil, "VENDOR" );
	addTradeSkill( "Lesser Wizard's Robe", 135, nil, "Trainer" );
	addTradeSkill( "Spider Silk Slippers", 140, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Azure Silk Pants", 140, nil, "Trainer" );
	addTradeSkill( "Azure Silk Gloves", 145, nil, "VENDOR" );
	addTradeSkill( "Azure Silk Hood", 145, nil, "Trainer" );
	addTradeSkill( "Hands of Darkness", 145, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Azure Silk Vest", 150, nil, "Trainer" );
	addTradeSkill( "Small Silk Pack", 150, nil, "Trainer" );
	addTradeSkill( "Robes of Arcana", 150, nil, "Mob Drop: Dark Strand Voidcaller (Darkshore, Defias Enchanter (Duskwood)" );
	addTradeSkill( "Truefaith Gloves", 150, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Dark Silk Shirt", 155, nil, "VENDOR" );
	addTradeSkill( "White Swashbuckler's Shirt", 160, nil, "Trainer" );
	addTradeSkill( "Silk Headband", 160, nil, "Trainer" );
	addTradeSkill( "Enchanter's Cowl", 165, nil, "VENDOR" );
	addTradeSkill( "Green Silk Armor", 165, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Shadow Hood", 170, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Formal White Shirt", 170, nil, "Trainer" );
	addTradeSkill( "Earthen Vest", 170, nil, "Trainer" );
	addTradeSkill( "Bolt of Mageweave", 175, nil, "Trainer" );
	addTradeSkill( "Boots of the Enchanter", 175, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Green Silk Pack", 175, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Red Swashbuckler's Shirt", 175, nil, "Trainer" );
	addTradeSkill( "Azure Silk Belt", 175, nil, "Trainer" );
	addTradeSkill( "Crimson Silk Belt", 175, nil, "Trainer" );
	addTradeSkill( "Azure Silk Cloak", 175, nil, "VENDOR" );
	addTradeSkill( "Spider Belt", 180, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Green Silken Shoulders", 180, nil, "Trainer" );
	addTradeSkill( "Crimson Silk Cloak", 180, nil, "VENDOR" );
	addTradeSkill( "Long Silken Cloak", 185, nil, "Trainer" );
	addTradeSkill( "Rich Purple Silk Shirt", 185, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Black Silk Pack", 185, nil, "Mob Drop: Syndicate Spy (Alterac Mountains), Theramore Infiltrator (Dustwallow Marsh), Shadowy Assassin (Hillsbrad Foothills)" );
	addTradeSkill( "Crimson Silk Vest", 185, nil, "Trainer" );
	addTradeSkill( "Robe of Power", 190, nil, "Trainer" );
	addTradeSkill( "Crimson Silk Shoulders", 190, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Azure Shoulders", 190, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Green Holiday Shirt", 190, nil, "You can get this randomly as a reward from a Christmas quest.  It's also a drop from Father Winter" );
	addTradeSkill( "Earthen Silk Belt", 195, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Crimson Silk Pantaloons", 195, nil, "Trainer" );
	addTradeSkill( "Icy Cloak", 200, nil, "VENDOR" );
	addTradeSkill( "Star Belt", 200, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Black Swashbuckler's Shirt", 200, nil, "VENDOR" );
	addTradeSkill( "Crimson Silk Robe", 205, nil, "VENDOR" );
	addTradeSkill( "Black Mageweave Vest", 205, nil, "Trainer" );
	addTradeSkill( "Black Mageweave Leggings", 205, nil, "Trainer" );
	addTradeSkill( "Crimson Silk Gloves", 210, nil, "Trainer" );
	addTradeSkill( "Black Mageweave Robe", 210, nil, "Trainer" );
	addTradeSkill( "Shadoweave Pants", 210, nil, "Trainer" );
	addTradeSkill( "Black Mageweave Gloves", 215, nil, "Trainer" );
	addTradeSkill( "Shadoweave Robe", 215, nil, "Trainer" );
	addTradeSkill( "Red Mageweave Vest", 215, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "White Bandit Mask", 215, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Red Mageweave Pants", 215, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Orange Mageweave Shirt", 215, nil, "Trainer" );
	addTradeSkill( "Orange Martial Shirt", 220, nil, "VENDOR" );
	addTradeSkill( "Mageweave Bag", 225, nil, "Trainer" );
	addTradeSkill( "Red Mageweave Gloves", 225, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Dreamweave Gloves", 225, nil, "Trainer" );
	addTradeSkill( "Cindercloth Robe", 225, nil, "Trainer" );
	addTradeSkill( "Dreamweave Vest", 225, nil, "Trainer" );
	addTradeSkill( "Shadoweave Gloves", 225, nil, "Trainer" );
	addTradeSkill( "Enchanted Mageweave Pouch", 225, nil, "VENDOR" );
	addTradeSkill( "Black Mageweave Headband", 230, nil, "Trainer" );
	addTradeSkill( "Black Mageweave Boots", 230, nil, "Trainer" );
	addTradeSkill( "Black Mageweave Shoulders", 230, nil, "Trainer" );
	addTradeSkill( "Lavender Mageweave Shirt", 230, nil, "VENDOR" );
	addTradeSkill( "Shadoweave Shoulders", 235, nil, "Trainer" );
	addTradeSkill( "Simple Black Dress", 235, nil, "Trainer" );
	addTradeSkill( "Red Mageweave Shoulders", 235, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Red Mageweave Bag", 235, nil, "Trainer" );
	addTradeSkill( "Pink Mageweave Shirt", 235, nil, "VENDOR" );
	addTradeSkill( "Admiral's Hat", 240, nil, "VENDOR" );
	addTradeSkill( "Shadoweave Boots", 240, nil, "Trainer" );
	addTradeSkill( "Red Mageweave Headband", 240, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Tuxedo Shirt", 240, nil, "VENDOR" );
	addTradeSkill( "Shadoweave Mask", 245, nil, "Reward from quest (The Undermarket) that starts from Nilith Lokrav (Searing Gorge)");
	addTradeSkill( "Cindercloth Boots", 245, nil, "Trainer" );
	addTradeSkill( "Tuxedo Pants", 245, nil, "VENDOR" );
	addTradeSkill( "White Wedding Dress", 250, nil, "VENDOR" );
	addTradeSkill( "Dreamweave Circlet", 250, nil, "Trainer" );
	addTradeSkill( "Tuxedo Jacket", 250, nil, "VENDOR" );
	addTradeSkill( "Bolt of Runecloth", 250, nil, "Trainer" );
	addTradeSkill( "Mooncloth", 250, nil, "VENDOR" );
	addTradeSkill( "Festive Red Dress", 250, nil, "Reward from quest during Lunar Festival that starts in Moonglade" );
	addTradeSkill( "Festival Dress", 250, nil, "Reward from quest during Lunar Festival that starts in Moonglade" );
	addTradeSkill( "Festive Red Pant Suit", 250, nil, "Reward from quest during Lunar Festival that starts in Moonglade" );
	addTradeSkill( "Runecloth Belt", 255, nil, "Trainer" );
	addTradeSkill( "Frostweave Tunic", 255, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Frostweave Robe", 255, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Runecloth Robe", 260, nil, "VENDOR" );
	addTradeSkill( "Runecloth Bag", 260, nil, "VENDOR" );
	addTradeSkill( "Runecloth Tunic", 260, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Cindercloth Vest", 260, nil, "Mob Drop: Twilight Fire Guard (Searing Gorge)" );
	addTradeSkill( "Soul Pouch", 260, nil, "VENDOR" );
	addTradeSkill( "Runecloth Cloak", 265, nil, "VENDOR" );
	addTradeSkill( "Ghostweave Belt", 265, nil, "Mob Drop: Lingering Highborne (Azshara)" );
	addTradeSkill( "Frostweave Gloves", 265, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Cindercloth Gloves", 270, nil, "Mob Drop: Twilight Fire Guard (Searing Gorge)" );
	addTradeSkill( "Brightcloth Gloves", 270, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Ghostweave Gloves", 270, nil, "Mob Drop: Lingering Highborne (Azshara), Unseen Servant (Eastern Plaguelands)" );
	addTradeSkill( "Brightcloth Robe", 270, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Ghostweave Vest", 275, nil, "Mob Drop: Unseen Servant (Eastern Plaguelands)" );
	addTradeSkill( "Runecloth Gloves", 275, nil, "VENDOR" );
	addTradeSkill( "Cindercloth Cloak", 275, nil, "Mob Drop: Thaurissan Firewalker (Burning Steppes)" );
	addTradeSkill( "Felcloth Pants", 275, nil, "VENDOR" );
	addTradeSkill( "Brightcloth Cloak", 275, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Wizardweave Leggings", 275, nil, "Mob Drop: Dark Summoner (Eastern Plaguelands and Stratholme)" );
	addTradeSkill( "Cloak of Fire", 275, nil, "Mob Drop: Overmaster Pyron (Blackrock Mountain) - Binds when picked up" );
	addTradeSkill( "Enchanted Runecloth Bag", 275, nil, "VENDOR" );
	addTradeSkill( "Cenarion Herb Bag", 275, nil, "VENDOR" );
	addTradeSkill( "Runecloth Boots", 280, nil, "VENDOR" );
	addTradeSkill( "Frostweave Pants", 280, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Cindercloth Pants", 280, nil, "Mob Drop: Thaurissan Firewalker (Burning Steppes)" );
	addTradeSkill( "Robe of Winter Night", 285, nil, "Mob Drop: Cobalt Mageweaver (Winterspring)" );
	addTradeSkill( "Felcloth Boots", 285, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Runecloth Pants", 285, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Felcloth Bag", 285, nil, "Book spawns after defeating Jandice in Scholomance.  Must have skill level 285 to learn."  );
	addTradeSkill( "Brightcloth Pants", 290, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Mooncloth Leggings", 290, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Mooncloth Boots", 290, nil, "Reward from quest (Sacred Cloth).  Receive quest from Meilosh in Timbermaw Hold.  Requires friendly reputation with Timbermaw Hold."  );
	addTradeSkill( "Ghostweave Pants", 290, nil, "Mob Drop: Spectral Citizen (Stratholme)" );
	addTradeSkill( "Felcloth Hood", 290, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Wisdom of the Timbermaw", 290, nil, "You can buy this from Meilosh in Felwood when you are honoroed with Timbermaw Hold" );
	addTradeSkill( "Argent Boots", 290, nil, "You can buy this from an Argent Dawn Quartermaster when you are honored with Argent Dawn" );
	addTradeSkill( "Runecloth Headband", 295, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Mooncloth Bag", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Wizardweave Robe", 300, nil, "Mob Drop: Dark Caster (Eastern Plaguelands)" );
	addTradeSkill( "Mooncloth Vest", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Mooncloth Shoulders", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Runecloth Shoulders", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Wizardweave Turban", 300, nil, "Mob Drop: Dark Caster (Eastern Plaguelands)" );
	addTradeSkill( "Felcloth Robe", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Mooncloth Circlet", 300, nil );
	addTradeSkill( "Gordok Ogre Suit", 300, nil, "Can learn recipe after completing quest (The Gordok Ogre Suit) obtained from Knot Thimblejack from Dire Maul" );
	addTradeSkill( "Felcloth Shoulders", 300, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Gloves of Spell Mastery", 300, nil );
	addTradeSkill( "Bottomless Bag", 300, nil );
	addTradeSkill( "Truefaith Vestments", 300, nil, "Mob Drop: Balnazzar (Stratholme)", "Priest" );
	addTradeSkill( "Robe of the Archmage", 300, nil, "Mob Drop: Firebrand Pyromancer (Hall of Blackhand)", "Mage" );
	addTradeSkill( "Robe of the Void", 300, nil, "Mob Drop: Darkmaster Gandling (Scholomance)", "Warlock" );
	addTradeSkill( "Flarecore Mantle", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are honored with Thorium Brotherhood"  );
	addTradeSkill( "Flarecore Gloves", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are friendly with Thorium Brotherhood"  );
	addTradeSkill( "Flarecore Wraps", 300, nil, "Mob Drop: Molten Core bosses" );
	addTradeSkill( "Belt of the Archmage", 300, nil, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Reaver and Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Felcloth Gloves", 300, nil, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Bushwacker, Gordok Reaver and Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Inferno Gloves", 300, nil, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Guard Slip'kik, Gordok Reaver and Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Mooncloth Gloves", 300, nil, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Bushwacker, Gordok Reaver and Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Cloak of Warding", 300, nil, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Reaver (Dire Maul)" );
	addTradeSkill( "Mooncloth Robe", 300, nil, "VENDOR" );
	addTradeSkill( "Mantle of the Timbermaw", 300, nil, "You can buy this from Meilosh in Felwood when you are revered with Timbermaw Hold" );
	addTradeSkill( "Argent Shoulders", 300, nil, "You can buy this from an Argent Dawn Quartermaster when you are revered with Argent Dawn" );
	addTradeSkill( "Flarecore Robe", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Flarecore Leggings", 300, nil, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Bloodvine Boots", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are friendly with Zandalar Tribe" );
	addTradeSkill( "Bloodvine Leggings", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Bloodvine Vest", 300, nil, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Runed Stygian Belt", 300, nil, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Runed Stygian Boots", 300, nil, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Runed Stygian Leggings", 300, nil, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Core Felcloth Bag", 300, nil, "Mob Drop: Lord Kazzok (Blasted Lands) and Molten Core bosses" );
	addTradeSkill( "Big Bag of Enchantment", 300, nil, "Mob Drop: Magister Kalendris (Dire Maul)" );
	addTradeSkill( "Satchel of Cenarius", 300, nil, "You can buy this from Mishta in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Gaea's Embrace", 300, nil, "You can buy this from Mishta in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Sylvan Crown", 300, nil, "You can buy this from Mishta in Silithus when you are honored with Cenarion Circle" );
	addTradeSkill( "Sylvan Shoulders", 300, nil, "You can buy this from Mishta in Silithus when you are friendly with Cenarion Circle" );
	addTradeSkill( "Sylvan Vest", 300, nil, nil, "You can buy this from Mishta in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Glacial Cloak", 300, nil, "You can learn this from Master Craftsman Omarion in Naxxramas when you are exalted with Argent Dawn" );
	addTradeSkill( "Glacial Gloves", 300, nil, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Glacial Vest", 300, nil, "You can learn this from Master Craftsman Omarion in Naxxramas when you are exalted with Argent Dawn" );
	addTradeSkill( "Glacial Wrists", 300, nil, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );

	addTradeSkill( "Netherweave Net", 300, nil, "Trainer" );
	addTradeSkill( "Bolt of Netherweave", 300, nil, "Trainer" );
	addTradeSkill( "Netherweave Bracers", 310, nil, "Trainer" );
	addTradeSkill( "Netherweave Belt", 310, nil, "Trainer" );
	addTradeSkill( "Netherweave Bag", 315, nil, "Trainer" );
	addTradeSkill( "Netherweave Gloves", 320, nil, "Trainer" );
	addTradeSkill( "Bolt of Imbued Netherweave", 325, nil, "VENDOR" );
	addTradeSkill( "Netherweave Pants", 325, nil, "Trainer" );
	addTradeSkill( "Netherweave Boots", 335, nil, "Trainer" );
	addTradeSkill( "Mystic Spellthread", 335, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Silver Spellthread", 335, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Imbued Netherweave Bag", 340, nil, "VENDOR" );
	addTradeSkill( "Netherweave Robe", 340, nil, "VENDOR" );
	addTradeSkill( "Imbued Netherweave Pants", 340, nil, "VENDOR" );
	addTradeSkill( "Bag of Jewels", 340, nil, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Bolt of Soulcloth", 345, nil, "VENDOR" );
	addTradeSkill( "Netherweave Tunic", 345, nil, "VENDOR" );
	addTradeSkill( "Primal Mooncloth", 350, nil, "VENDOR" );
	addTradeSkill( "Imbued Netherweave Boots", 350, nil, "VENDOR" );
	addTradeSkill( "Arcanoweave Bracers", 350, nil, "BoP mob drop from Arcatraz Sentinels in The Arcatraz" );
	addTradeSkill( "Unyielding Bracers", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Bracers of Havok", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Blackstrike Bracers", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Cloak of the Black Void", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Cloak of Eternity", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "White Remedy Cape", 350, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Spellcloth", 350, nil, "VENDOR" );
	addTradeSkill( "Shadowcloth", 350, nil, "VENDOR" );
	addTradeSkill( "Cloak of Arcane Evasion", 350, nil, "You can buy this from Nakodu in Shattrath City when you are honored with Lower City" );
	addTradeSkill( "Flameheart Bracers", 350, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are friendly with Aldor" );
	addTradeSkill( "Spellfire Belt", 355, "Spellfire", "VENDOR" );
	addTradeSkill( "Frozen Shadoweave Shoulders", 355, "Shadoweave", "VENDOR" );
	addTradeSkill( "Primal Mooncloth Belt", 355, "Mooncloth", "VENDOR" );
	addTradeSkill( "Soulcloth Gloves", 355, nil, "VENDOR" );
	addTradeSkill( "Imbued Netherweave Robe", 360, nil, "VENDOR" );
	addTradeSkill( "Imbued Netherweave Tunic", 360, nil, "VENDOR" );
	addTradeSkill( "Arcanoweave Boots", 360, nil, "BoP mob drop from Sunseeker Astromages in The Mechanar" );
	addTradeSkill( "Flameheart Gloves", 360, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Spellfire Gloves", 365, "Spellfire", nil, "VENDOR" );
	addTradeSkill( "Frozen Shadoweave Boots", 365, "Shadoweave", nil, "VENDOR" );
	addTradeSkill( "Primal Mooncloth Shoulders", 365, "Mooncloth", nil, "VENDOR" );
	addTradeSkill( "Soulcloth Shoulders", 365, nil, "BoP mob drop from Phantom Attendants in Karazhan" );
	addTradeSkill( "Unyielding Girdle", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Girdle of Ruination", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Black Belt of Knowledge", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Resolute Cape", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Vengeance Wrap", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Manaweave Cloak", 365, nil, "World Drop (Buy on AH)" );
	addTradeSkill( "Arcanoweave Robe", 370, nil, "BoP mob drop from Panthaleon the Calculator in The Mechanar" );
	addTradeSkill( "Flameheart Vest", 370, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );
	addTradeSkill( "Spellfire Vest", 370, "Spellfire", "Trainer" );
	addTradeSkill( "Spellfire Bag", 375, nil, "Vendor" );
	addTradeSkill( "Frozen Shadoweave Vest", 375, "Shadoweave", "VENDOR" );
	addTradeSkill( "Ebon Shadowbag", 375, "Mooncloth", "Vendor" );
	addTradeSkill( "Primal Mooncloth Robe", 375, "Mooncloth", "Vendor" );
	addTradeSkill( "Primal Mooncloth Bag", 375, nil, "VENDOR" );
	addTradeSkill( "Soulcloth Vest", 375, nil, "BoP mob drop from Phantom Valet in Karazhan" );
	addTradeSkill( "Runic Spellthread", 375, nil, "You can buy this from Quartermaster Enuril in Shattrath when you are exalted with Scryers" );
	addTradeSkill( "Golden Spellthread", 375, nil, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );
	addTradeSkill( "Whitemend Pants", 375, nil, "BoP mob drop from Dalliah the Doomsayer in The Arcatraz" );
	addTradeSkill( "Spellstrike Pants", 375, nil, "BoP mob drop from Murmur in Shadow Labyrinth" );
	addTradeSkill( "Battlecast Pants", 375, nil, "BoP mob drop from Thorngrin the Tender in The Botanica" );
	addTradeSkill( "Whitemend Hood", 375, nil, "BoP mob drop from Warp Splinter in The Botanica" );
	addTradeSkill( "Spellstrike Hood", 375, nil, "BoP mob drop from Grand Warlock Nethekurse in The Shattered Halls" );
	addTradeSkill( "Battlecast Hood", 375, nil, "BoP mob drop from Warlord Kalithresh" );

end

-- Initializes the array adding all Smelting recipes.  As of 2.2 there are 20 recipes

function AckisRecipeList:InitSmelting()
  
	AckisRecipeList.InitializeRecipeArray();

  	-- Original Game Recipes
	addTradeSkill( "Smelt Copper", 1, "Trainer" );
	addTradeSkill( "Smelt Tin", 65, "Trainer" );
	addTradeSkill( "Smelt Bronze", 65, "Trainer" );
	addTradeSkill( "Smelt Silver", 75, "Trainer" );
	addTradeSkill( "Smelt Iron", 125, "Trainer" );
	addTradeSkill( "Smelt Gold", 155, "Trainer" );
	addTradeSkill( "Smelt Steel", 165, "Trainer" );
	addTradeSkill( "Smelt Mithril", 175, "Trainer" );
	addTradeSkill( "Smelt Dark Iron", 230, "Quest in BRD, which requires 20 Gold Bars, 2 Star Rubies, and 10 Truesilver Bars to BRD.  Talk to Gloom'Rel, who is one of the undead in the Summoner's Tomb." );
	addTradeSkill( "Smelt Truesilver", 230, "Trainer" );
	addTradeSkill( "Smelt Thorium", 250, "Trainer" );
	addTradeSkill( "Smelt Elementium", 270, "Mind control Krixix in BWL.  On the pet bar there will be an option to train this ability for yourself and others." );

	-- Burning Crusade Recipes
	addTradeSkill( "Fire Sunder", 300, "Trainer" );
	addTradeSkill( "Earth Shatter", 300, "Trainer" );
	addTradeSkill( "Smelt Fel Iron", 300, "Trainer" );
	addTradeSkill( "Smelt Adamantite", 350, "Trainer" );
	addTradeSkill( "Smelt Felsteel", 350, "Trainer" );
	addTradeSkill( "Smelt Eternium", 350, "Trainer" );
	addTradeSkill( "Smelt Khorium", 375, "Trainer" );
	addTradeSkill( "Smelt Hardened Adamantite", 375, "Trainer" );

	-- Wrath of the Litch King Recipes

end

-- Checks to see if a recipe is known or not.

function AckisRecipeList:CheckRecipe(RecipeName)

	if (RecipeListing[ RecipeName ]) then

		-- Update array that recipe was found
		AckisRecipeList:foundTradeSkill(RecipeName);
	
	else

		-- Notify users in chat that skill is missing from the database.
		AckisRecipeList:printMissingSkill(RecipeName);

	end

end

-- Scans your recipe book for Trade Skill Recipes

function AckisRecipeList:ScanTradeSkills(CurrentTradeSkill)

	-- Identify scan occuring in chat
	DEFAULT_CHAT_FRAME:AddMessage( "Currently scanning " .. CurrentTradeSkill .. " recipes." );

	-- Scan through all recipes
	for i = 1, GetNumTradeSkills() do

		skillName, skillType, _, _ = GetTradeSkillInfo(i);

		-- Ignore all trade skill headers
		if (skillType ~= "header") then

			AckisRecipeList:CheckRecipe(skillName);

		-- If it is a header then expand it so scanning can continue
		else

			ExpandTradeSkillSubClass(i);
		
		end

	end
	
end

-- Scans your recipe book for Craft Skill Recipes

function AckisRecipeList:ScanCraftSkills(CurrentTradeSkill)

	-- Identify scan occuring in chat
	DEFAULT_CHAT_FRAME:AddMessage( "Currently scanning " .. CurrentTradeSkill .. " recipes." );

	-- Scan through all recipes
	for i = 1, GetNumCrafts() do

		skillName, craftSubSpellName, skillType, numAvailable, isExpanded, trainingPointCost, requiredLevel = GetCraftInfo(i); -- Don't need a lot of this information, what to do with it?

		-- Ignore all trade skill headers
		if (skillType ~= "header") then

			AckisRecipeList:CheckRecipe(skillName);

		-- If it is a header then expand it so scanning can continue
		else

			ExpandCraftSkillLine(i);

		end

	end

end

-- Function to be called when /arl scan is run.
function AckisRecipeList:AckisRecipeList_Command()

	if ( SkillType == nil ) then

		DEFAULT_CHAT_FRAME:AddMessage( "Please open trade skill window to scan." );

	-- Trade type skills
	elseif SkillType == "Trade" then

		-- Get the name of the current trade skill opened, along with the current level of the skill. 
		local CurrentProfession, CurrentProfessionLevel, _ = GetTradeSkillLine();

		-- Initialize the profession tables depending on which skill window is opened.
		if CurrentProfession == "Alchemy" then

			-- Add all alchemy recipes to the table
			AckisRecipeList:InitAlchemy();
		
		elseif CurrentProfession == "Blacksmithing" then
		
			-- Add all blacksmithing recipes to the table
			AckisRecipeList:InitBlackSmith();

		elseif CurrentProfession == "Cooking" then

			-- Add all cooking recipes to the table
			AckisRecipeList:InitCooking();

		elseif CurrentProfession == "Engineering" then
		
			-- Add all engineering recipes to the table
			AckisRecipeList:InitEngineering();
	
		elseif CurrentProfession == "First Aid" then

			-- Add all first aid recipes to the table
			AckisRecipeList:InitFirstAid();

		elseif CurrentProfession == "Leatherworking" then

			-- Add all leatherworking recipes to the table		
			AckisRecipeList:InitLeatherWorking();

		elseif CurrentProfession == "Poisons" then

			-- Add all rogue poisons recipes to the table
			AckisRecipeList:InitRoguePoison();

		elseif CurrentProfession == "Smelting" then

			-- Add all smelting recipes to the table
			AckisRecipeList:InitSmelting();

		elseif CurrentProfession == "Tailoring" then

			-- Add all tailoring recipes to the table
			AckisRecipeList:InitTailoring();

		-- Burning Crusade Professions
		elseif CurrentProfession == "Jewelcrafting" then

			-- Add all jewelcrafting recipes to the table
			AckisRecipeList:InitJewelcrafting();

		else

			DEFAULT_CHAT_FRAME:AddMessage("You have opened up a trade skill window which is not supported by this add-on.  The trade skill is " .. CurrentProfession .. ".  Please provide the author of the add-on with this information.")
		
		end

		AckisRecipeList:ScanTradeSkills(CurrentProfession);

		AckisRecipeList:DisplayRecipeResults();

	-- Craft type skills
	elseif SkillType == "Craft" then

		-- Get the name of the current craft.
		local CurrentProfession = GetCraftName();

		-- Get the current level of the craft.
		local CurrentProfessionLevel = getglobal( "CraftRankFrame" ):GetValue(); --Better way to do this?

		-- Initialize the profession tables depending on which skill window is opened.
		if CurrentProfession == "Enchanting" then

			-- Add all alchemy recipes to the table
			AckisRecipeList:InitEnchanting();

		elseif CurrentProfession == "Beast Training" then

			DEFAULT_CHAT_FRAME:AddMessage("Beast Training is not supported by this add-on currently.  Your Beast Training level is " .. CurrentProfessionLevel .. ".  Support will be added in a future version.")
	
		else

			DEFAULT_CHAT_FRAME:AddMessage("You have opened up a trade skill window which is not supported by this add-on.  The trade skill is " .. CurrentProfession .. ".  Please provide the author of the add-on with this information.")

		end

		AckisRecipeList:ScanCraftSkills(CurrentProfession);

		AckisRecipeList:DisplayRecipeResults();		

	end

	AckisRecipeList:ResetVariables();

end
